@@ -319,7 +319,7 @@ ha:cschem-sheet-v1 {
 					ha:text.2 { x1=110000; y1=144000; dyntext=1; stroke=wire; text=%../A.name%; floater=1; }
 				}
 				ha:attrib {
-					name=res_led
+					name=./res_led
 					ha:role = { value=wire-net; prio=0; }
 				}
 			}
