@@ -450,11 +450,6 @@ ha:cschem-sheet-v1 {
 					sym-source=sch-rnd default symbol lib
 				}
 			}
-			ha:connection.37 {
-				li:conn {
-					/2/36/1/1
-				}
-			}
 			ha:group.38 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAFL;
 				li:objects {
@@ -540,30 +535,6 @@ ha:cschem-sheet-v1 {
 					role=symbol
 				}
 			}
-			ha:group.64 {
-				uuid=iNOQfJpO6hT/HFDFGjoAAAFT;
-				li:objects {
-				}
-				ha:attrib {
-					ha:role = { value=wire-net; prio=0; }
-				}
-			}
-			ha:group.65 {
-				uuid=iNOQfJpO6hT/HFDFGjoAAAFU;
-				li:objects {
-				}
-				ha:attrib {
-					ha:role = { value=wire-net; prio=0; }
-				}
-			}
-			ha:group.66 {
-				uuid=iNOQfJpO6hT/HFDFGjoAAAFV;
-				li:objects {
-				}
-				ha:attrib {
-					ha:role = { value=wire-net; prio=0; }
-				}
-			}
 			ha:group.67 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAFW;
 				li:objects {
@@ -612,11 +583,6 @@ ha:cschem-sheet-v1 {
 					/2/21/1/1
 				}
 			}
-			ha:connection.74 {
-				li:conn {
-					/2/63/3/1
-				}
-			}
 			ha:group.75 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAFX;
 				x=188000; y=76000;
@@ -741,17 +707,6 @@ ha:cschem-sheet-v1 {
 					role=symbol
 				}
 			}
-			ha:connection.96 {
-				li:conn {
-					/2/95/2/1
-				}
-			}
-			ha:connection.97 {
-				li:conn {
-					/2/95/4/1
-					/2/93
-				}
-			}
 			ha:group.98 {
 				uuid=iNOQfJpO6hT/HFDFGjoAAAFj;
 				x=28000; y=72000; mirx=1;
@@ -782,11 +737,6 @@ ha:cschem-sheet-v1 {
 					sym-source=sch-rnd default symbol lib
 				}
 			}
-			ha:connection.99 {
-				li:conn {
-					/2/98/1/1
-				}
-			}
 			ha:connection.100 {
 				li:conn {
 					/2/4/11
