@@ -234,4 +234,7 @@ csch_acomp_t *csch_acomp_new(csch_abstract_t *abs, csch_hlevel_t *hlev, csch_asc
 
 csch_aport_t *csch_aport_get(csch_abstract_t *abs, csch_acomp_t *comp, const char *name, int alloc);
 
+/* return aport's parent name or <sheet> if it's global */
+#define APORT_PARENT_NAME(ap) (((ap)->parent == NULL) ? "<sheet>" : (ap)->parent->name)
+
 #endif
