@@ -41,6 +41,7 @@
 #include "concrete.h"
 #include "abstract.h"
 #include "project.h"
+#include "extobj.h"
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/rnd_printf.h>
 #include <librnd/core/error.h>
@@ -612,6 +613,7 @@ static int undo_attr_modify_swap(void *udata)
 	csch_attrib_t *a;
 
 	csch_cobj_redraw(u->obj);
+	csch_extrobj_attr_edit_pre(u->obj, u->key);
 
 	a = htsp_get(&u->obj->attr, u->key);
 	if (u->a != NULL)
@@ -623,6 +625,7 @@ static int undo_attr_modify_swap(void *udata)
 	csch_attr_side_effects(u->obj, u->key);
 
 	csch_sheet_set_changed(u->obj->hdr.sheet, 1);
+	csch_extrobj_attr_edit_post(u->obj, u->key);
 	notify(&u->obj->hdr);
 	return 0;
 }
