@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - libcschem (core library)
- *  Copyright (C) 2018..2020,2022,2023 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2018..2020,2022..2024 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022, Entrust in 2023)
  *
@@ -57,6 +57,7 @@
 #include "project.h"
 #include "abstract.h"
 #include "libcschem.h"
+#include "extobj.h"
 
 RND_INLINE csch_role_t csch_role_str2role(const char *str)
 {
@@ -68,6 +69,7 @@ RND_INLINE csch_role_t csch_role_str2role(const char *str)
 	if (strcmp(str, "terminal") == 0)     return CSCH_ROLE_TERMINAL;
 	if (strcmp(str, "wire-net") == 0)     return CSCH_ROLE_WIRE_NET;
 	if (strcmp(str, "junction") == 0)     return CSCH_ROLE_JUNCTION;
+	if (strcmp(str, "extobj-gfx") == 0)   return CSCH_ROLE_EXTOBJ_GFX;
 	return CSCH_ROLE_invalid;
 }
 
@@ -121,8 +123,11 @@ csch_cgrp_t *csch_cgrp_dup_into(csch_sheet_t *sheet, csch_cgrp_t *dst, const csc
 	for(e = htip_first(&src->id2obj); e != NULL; e = htip_next(&src->id2obj, e))
 		csch_cobj_dup(sheet, dst, (csch_chdr_t *)e->value, 1, 0);
 
-	if (copy_attr)
+	if (copy_attr) {
+		dst->extobj_inhibit++;
 		csch_cobj_attrib_copy_all(sheet, dst, src);
+		dst->extobj_inhibit--;
+	}
 
 	return dst;
 }
@@ -327,6 +332,8 @@ void csch_cgrp_attrib_update(csch_sheet_t *sheet, csch_cgrp_t *grp, int prio, co
 		csch_role_set(grp, val);
 		csch_cgrp_update_dsply_recurse(sheet, grp); /* need to move all opjects to the wire layer */
 	}
+	if (strcmp(key, "extobj") == 0)
+		grp->extobj = csch_extobj_lookup(val);
 }
 
 csch_ahdr_t *csch_cgrp_get_abstract(csch_sheet_t *sheet, const csch_cgrp_t *grp, long idx)
