@@ -68,4 +68,16 @@ void csch_cpoly_modify(csch_sheet_t *sheet, csch_cpoly_t *poly, int *has_stroke,
 csch_vtcoutline_t *csch_cpoly_modify_geo_begin(csch_sheet_t *sheet, csch_cpoly_t *poly, void **cookie, int undoable);
 void csch_cpoly_modify_geo_end(csch_sheet_t *sheet, csch_cpoly_t *poly, void **cookie);
 
+/* Returns the contour object(s) near x;y with search "radius" r (really a
+   query box width). Returns:
+     - 0: no object found (x;y is within or outside of the poly)
+     - 1: obj_idx[0] loaded (x;y is on the middle of a contour object)
+     - 2: obj_idx[0] and obj_idx[1] loaded (x;y is near enough to a corner);
+          the corner point is at obj_idx[0] end while obj_idx[1] start point */
+int csch_poly_contour_objs_at(csch_cpoly_t *poly, csch_coord_t x, csch_coord_t y, csch_coord_t r, long obj_idx[2]);
+
+/* Returns whether x;y is an endpoint of poly's idxth contour object. If idx
+   is invalid, returns 0. */
+int csch_poly_contour_obj_ends_at(csch_cpoly_t *poly, long idx, csch_coord_t x, csch_coord_t y);
+
 #endif
