@@ -119,7 +119,7 @@ void csch_text_invalidate_all_sheet(csch_sheet_t *sheet, int dynonly);
 void csch_text_invalidate_all_project(csch_project_t *prj, int dynonly);
 
 /* Return rendered text; never returns NULL. */
-csch_inline const char *csch_text_get_rtext(csch_text_t *text);
+RND_INLINE const char *csch_text_get_rtext(csch_text_t *text);
 
 /* Return the number of non-7-bit-ASCII-printable characters in rendered
    txt string */
@@ -127,7 +127,7 @@ int csch_text_invalid_chars(csch_text_t *txt);
 
 
 /*** Implementation ***/
-csch_inline const char *csch_text_get_rtext(csch_text_t *text)
+RND_INLINE const char *csch_text_get_rtext(csch_text_t *text)
 {
 	if (text->rtext == NULL)
 		csch_text_dyntext_render(text);
