@@ -27,5 +27,7 @@ typedef struct csch_project_s csch_project_t;
 typedef struct csch_view_s csch_view_t;
 typedef struct csch_view_eng_s csch_view_eng_t;
 
+/* for non-graphical sheets (non_graphical.h) */
+typedef struct csch_non_graphical_impl_s csch_non_graphical_impl_t;
 
 #endif
