@@ -491,7 +491,7 @@ static int compile_symbol(csch_abstract_t *dst, int viewid, csch_hier_path_t *hp
 
 
 	dst->ucnt.comp++;
-	if ((aname == NULL) || (aname->key == NULL) || (*aname->key == '\0')) {
+	if ((aname == NULL) || (aname->val == NULL) || (*aname->val == '\0') || (aname->key == NULL) || (*aname->key == '\0')) {
 		sprintf(tmpname, "anon_comp_%ld", dst->ucnt.comp);
 		orig_name = tmpname;
 	}
@@ -538,7 +538,7 @@ int csch_compile_connect_net_to(csch_anet_t **net, csch_ahdr_t *a, int allow_rec
 /*				rnd_trace("  connect to subsheet port's net %s\n", ap->subsheet_port->conn.net->name);*/
 				new_net = csch_cmp_merge_nets(*net, ap->subsheet_port->conn.net);
 				if (new_net == NULL) {
-					rnd_message(RND_MSG_ERROR, "csch_compile_connect_net_to(): failed to merge nets %s and %s at port %s:%s for hierarchic connection down\n", (*net)->name, ap->subsheet_port->conn.net->name, ap->parent->name, ap->name);
+					rnd_message(RND_MSG_ERROR, "csch_compile_connect_net_to(): failed to merge nets %s and %s at port %s:%s for hierarchic connection down\n", (*net)->name, ap->subsheet_port->conn.net->name, APORT_PARENT_NAME(ap), ap->name);
 					return -1;
 				}
 				*net = new_net;
@@ -557,12 +557,12 @@ int csch_compile_connect_net_to(csch_anet_t **net, csch_ahdr_t *a, int allow_rec
 				allowed = 1;
 
 			if (!allow_reconn && !allowed) {
-				rnd_message(RND_MSG_ERROR, "csch_compile_connect_net_to(): port %s:%s already connected\n(This error is generated because multiport_net_merge is disabled in the config)\n", ap->parent->name, ap->name);
+				rnd_message(RND_MSG_ERROR, "csch_compile_connect_net_to(): port %s:%s already connected\n(This error is generated because multiport_net_merge is disabled in the config)\n", APORT_PARENT_NAME(ap), ap->name);
 				return -1;
 			}
 			new_net = csch_cmp_merge_nets(*net, ap->conn.net);
 			if (new_net == NULL) {
-				rnd_message(RND_MSG_ERROR, "csch_compile_connect_net_to(): failed to merge nets %s and %s at port %s:%s\n", (*net)->name, ap->conn.net->name, ap->parent->name, ap->name);
+				rnd_message(RND_MSG_ERROR, "csch_compile_connect_net_to(): failed to merge nets %s and %s at port %s:%s\n", (*net)->name, ap->conn.net->name, APORT_PARENT_NAME(ap), ap->name);
 				return -1;
 			}
 			*net = new_net;
@@ -761,6 +761,7 @@ int csch_compile_sheet_(csch_abstract_t *dst, int viewid, csch_hier_path_t *hpat
 			case CSCH_ROLE_BUS_TERMINAL:
 			case CSCH_ROLE_HUB_POINT:
 			case CSCH_ROLE_JUNCTION:
+			case CSCH_ROLE_EXTOBJ_GFX:
 				break;
 		}
 	}
