@@ -168,6 +168,8 @@ void csch_sheet_uninit(csch_sheet_t *sheet)
 	sheet->newname = NULL;
 	free(sheet->hidlib.loadname);
 	sheet->hidlib.loadname = NULL;
+	free(sheet->hidlib.fullpath);
+	sheet->hidlib.fullpath = NULL;
 	free(sheet->loadfmt);
 	sheet->loadfmt = NULL;
 	free(sheet->design_dir);
@@ -180,6 +182,8 @@ void csch_sheet_free(csch_sheet_t *sheet)
 	rnd_event(&sheet->hidlib, CSCH_EVENT_SHEET_PREUNLOAD, NULL);
 	if (sheet->hidlib.project != NULL)
 		rnd_project_remove_design(sheet->hidlib.project, &sheet->hidlib);
+	if (sheet->hidlib.link.parent != NULL) /* NULL for buffers */
+		rnd_conf_state_del_design(&sheet->hidlib); /* also removes curr from rnd_designs */
 	csch_sheet_uninit(sheet);
 	free(sheet);
 }
