@@ -41,8 +41,10 @@ static const char *csch_evnames[] = {
 	"cschev_prj_compiled",
 	"cschev_prj_views_changed",
 	"cschev_prj_view_activated",
+	"cschev_prj_stance_changed",
 	"cschev_library_changed",
 	"cschev_selection_changed",
+	"cschev_drc_run",
 
 	"cschev_buffer_copy_custom",
 	"cschev_buffer_paste_custom"
