@@ -43,16 +43,19 @@ int csch_integrity_auto = 1;
 
 static void igy_brk() {}
 
-#define ASSERT(expr, reason) \
+#define ASSERT1(expr, reason, arg1) \
 	do { \
 		if (!(expr)) { \
 			const char *sheetname = sheet->hidlib.loadname; \
-			rnd_message(RND_MSG_ERROR,  "Integrity violation: " reason " (" #expr ") at " CSCH_IGY_LOC  ", sheet: %s; called from: %s\n", sheetname, called_from); \
+			rnd_message(RND_MSG_ERROR,  "Integrity violation: " reason, arg1); \
+			rnd_message(RND_MSG_ERROR,  " (" #expr ") at " CSCH_IGY_LOC  ", sheet: %s; called from: %s\n", sheetname, called_from); \
 			igy_brk(); \
 			res |= 1; \
 		} \
 	} while(0)
 
+#define ASSERT(expr, reason) ASSERT1(expr, reason, NULL)
+
 RND_INLINE int igy_cnc_grp(void *parent, csch_cgrp_t *grp, const char *called_from);
 
 RND_INLINE int igy_cnc_conn(void *parent, csch_conn_t *c, const char *called_from)
@@ -193,15 +196,13 @@ RND_INLINE int igy_wirenet(void *parent, csch_cgrp_t *wn, const char *called_fro
 			}
 		}
 		else {
-/*			htip_entry_t *e = htip_first(&wn->id2obj);
-			csch_chdr_t *o = e->value;*/
-			ASSERT(0, "wirenet conists of floaters only");
+			ASSERT1(0, "wirenet #%ld conists of floaters only", wn->hdr.oid);
 		}
 	}
 	else if (wnlen == 1) {
 		htip_entry_t *e = htip_first(&wn->id2obj);
 		csch_chdr_t *o = e->value;
-		ASSERT(!o->floater, "wirenet conists of floaters only");
+		ASSERT1(!o->floater, "wirenet #%ld conists of floaters only", wn->hdr.oid);
 	}
 	else if (wnlen < 1)
 		ASSERT(parent == wn->hdr.parent, "empty wirenet (invisible ghost group)");
@@ -211,7 +212,7 @@ RND_INLINE int igy_wirenet(void *parent, csch_cgrp_t *wn, const char *called_fro
 
 RND_INLINE int igy_cnc_grp(void *parent, csch_cgrp_t *grp, const char *called_from)
 {
-	int res = 0;
+	int res = 0, sym_mode_direct;
 	htip_entry_t *e;
 	csch_sheet_t *sheet = grp->hdr.sheet;
 
@@ -237,7 +238,10 @@ RND_INLINE int igy_cnc_grp(void *parent, csch_cgrp_t *grp, const char *called_fr
 			ASSERT(grp->data.ref.grp->hdr.sheet == grp->hdr.sheet, "grp_ref referee is on another sheet");
 	}
 
-	if (grp != &grp->hdr.sheet->indirect)
+	/* in symbol edit mode the sheet is a dummy sheet so does not have an uuid */
+	sym_mode_direct = sheet->is_symbol && (grp == &grp->hdr.sheet->direct);
+
+	if (grp != &grp->hdr.sheet->indirect && !sym_mode_direct)
 		ASSERT(!minuid_is_nil(grp->uuid), "grp without (instance) UUID");
 
 	return res;
