@@ -49,6 +49,7 @@ typedef enum {
 
 int csch_init(void);
 void csch_uninit(void);
+void csch_uninit_last(void); /* call this after fungw uninit */
 
 /* Insert all core actions to the global action hash */
 int csch_init_actions(void);
@@ -62,13 +63,31 @@ extern unsigned long csch_unit_k_allow, csch_unit_family_cschem;
 extern rnd_unit_t *csch_unit_k;    /* the standard cschem 'k' suffix unit (csch_coord_t * 1000) */
 extern rnd_unit_t *csch_unit_base; /* csch_coord_t, no suffix */
 
+/*** Config system ***/
+/* We have no access to the app's conf_core from the lib so we present
+   this API with pointers that the app can bind to native conf values */
+
 /* when multiple ports with the same component:port name connect to different
    nets: if true, allow merging those nets, else throw an error */
 extern const int *csch_cfg_multiport_net_merge;
 
+/* If zero: throw an error if a network is named on both parent and child
+   side of a hierarchic descend; else use *csch_cfg_hier_net_rename_prefer_top to
+   decide which name to keep */
+extern const int *csch_cfg_hier_net_allow_rename;
+
+/* If *csch_cfg_hier_net_allow_rename==1, this decides whether to use parent
+   (top) sheet's net name (1) or child (bottom) sheet's net name (0) */
+extern const int *csch_cfg_hier_net_rename_prefer_top;
+
+
 #define CSCH_CFG_(name, defval) (name == NULL ? defval : *name)
 #define CSCH_CFG(name, defval) CSCH_CFG_((csch_cfg_ ## name), (defval))
 
 extern minuid_session_t csch_minuid;
 
+/* Further app-side configuration defined in other headers:
+    - csch_app_load_sheet_cb()
+*/
+
 #endif
