@@ -63,8 +63,10 @@ csch_chdr_t *csch_op_remove(csch_sheet_t *sheet, csch_chdr_t *obj);
 csch_chdr_t *csch_cnc_remove(csch_sheet_t *sheet, csch_chdr_t *obj);
 
 
-/* migrate all objects from src to dst, leaving src empty (always undoable) */
+/* migrate all objects from src to dst, leaving src empty (always undoable);
+   the remember variant appends all new object pointers to dst_news */
 void csch_op_merge_into(csch_sheet_t *sheet, csch_cgrp_t *dst, csch_cgrp_t *src);
+void csch_op_merge_into_remember(csch_sheet_t *sheet, csch_cgrp_t *dst, csch_cgrp_t *src, vtp0_t *dst_news);
 
 int csch_isc_with_box(csch_chdr_t *obj, csch_rtree_box_t *box);
 
@@ -88,7 +90,7 @@ void csch_mirror(csch_sheet_t *sheet, csch_chdr_t *obj, csch_coord_t mcx, csch_c
 
 /* Copy or move src into the dst group; always undoable */
 csch_chdr_t *csch_op_copy_into(csch_sheet_t *sheet, csch_cgrp_t *dst, csch_chdr_t *src);
-void csch_op_move_into(csch_sheet_t *sheet, csch_cgrp_t *dst, csch_chdr_t *src, int restore_conns, int undoable_conns);
+csch_chdr_t *csch_op_move_into(csch_sheet_t *sheet, csch_cgrp_t *dst, csch_chdr_t *src, int restore_conns, int undoable_conns);
 
 
 const csch_ops_t *csch_op_get(csch_ctype_t type);
