@@ -86,7 +86,8 @@ static int prio_cmp(const void *d1, const void *d2)
 typedef enum {
 	LIST_LOAD,
 	LIST_SAVE,
-	LIST_EXPORT
+	LIST_EXPORT,
+	LIST_IMPORT
 } io_list_dir_t;
 
 static void csch_plug_io_list(vtpr_t *res, const char *fn, const char *fmt, csch_plug_io_type_t type, io_list_dir_t dir)
@@ -110,6 +111,10 @@ static void csch_plug_io_list(vtpr_t *res, const char *fn, const char *fmt, csch
 				if (io->export_prio == NULL) continue;
 				p = io->export_prio(fn, fmt, type);
 				break;
+			case LIST_IMPORT:
+				if (io->import_prio == NULL) continue;
+				p = io->import_prio(fn, fmt, type);
+				break;
 		}
 
 		if (p > 0) {
@@ -623,7 +628,7 @@ int csch_export_project_abst(csch_abstract_t *abs, const char *fn_, const char *
 		return -1;
 
 	len = strlen(fn_);
-	fn = malloc(len+256); /* leave "enoguh room" for the extension */
+	fn = malloc(len+256); /* leave "enough room" for the extension */
 	memcpy(fn, fn_, len+1); /* copy \0 as well */
 	if (fn[len-1] == '*')
 		ext = fn + len - 1;
@@ -761,3 +766,43 @@ int csch_save_buffer(csch_sheet_t *buffer, const char *fn, const char *fmt)
 {
 	return csch_export_or_save_sheet(buffer, fn, fmt, SS_SAVE_BUFFER, 0);
 }
+
+int csch_import_attbl(rnd_design_t *dsg, const char *fn, const char *fmt)
+{
+	vtpr_t prios;
+	FILE *f;
+	long n;
+	int res = -1;
+
+	f = rnd_fopen(dsg, fn, "r");
+	if (f == NULL) {
+		rnd_message(RND_MSG_ERROR, "Can't open '%s' for read\n", fn);
+		return -1;
+	}
+
+	vtpr_init(&prios);
+	csch_plug_io_list(&prios, fn, fmt, CSCH_IOTYP_ATTBL, LIST_IMPORT);
+	for(n = 0; n < vtpr_len(&prios); n++) {
+		prio_t *pr = &prios.array[n];
+
+		if (pr->io->import_attbl == NULL)
+			continue;
+
+		rewind(f);
+		if ((pr->io->test_parse != NULL) && (pr->io->test_parse(f, fn, fmt, CSCH_IOTYP_ATTBL) != 0))
+			continue;
+
+		rewind(f);
+		if (pr->io->import_attbl(f, fn, fmt, (csch_sheet_t *)dsg) == 0) {
+			res = 0;
+			goto done;
+		}
+	}
+
+	rnd_message(RND_MSG_ERROR, "Failed to load '%s':\nNone of the attbl plugins could recognize the file format\n", fn);
+
+	done:;
+	fclose(f);
+	return res;
+}
+
