@@ -34,7 +34,7 @@
 #include <libcschem/plug_library.h>
 
 /* look up library root_path's real path, skipping the ? prefix */
-char *csch_lib_fs_realpath(rnd_design_t *hl, char *root_path);
+char *csch_lib_fs_realpath(rnd_design_t *hl, const char *root_path);
 
 /* map path dir recursively for library entries; check each entry with
    type_cb, if it returns invalid type, omit the entry. */
