@@ -2,7 +2,7 @@
  *                            COPYRIGHT
  *
  *  cschem - modular/flexible schematics editor - libcschem (core library)
- *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
+ *  Copyright (C) 2022, 2024 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
  *
@@ -44,3 +44,7 @@ csch_cgrp_t *csch_loclib_get_root_by_name(csch_sheet_t *sheet, const char *name,
    failure there's no root dir in indirect.
    Always frees src's fields. */
 int csch_loclib_get_roots(csch_lib_t **root_dir_out, csch_cgrp_t **root_grp_out, csch_lib_master_t *master, csch_sheet_t *sheet, csch_source_arg_t *src, int alloc, int *alloced);
+
+/* Reload all loclib entries from external libraries. Used in actions like
+   SymlibReloadAllLocal() */
+long csch_loclib_reload_all(csch_sheet_t *sheet, csch_lib_root_t *libroot);
