@@ -175,13 +175,20 @@ int csch_lht_parse_attribs_(csch_sheet_t *sheet, csch_chdr_t *dsth, csch_attribs
 	if ((subtree == NULL) || (subtree->type != LHT_HASH))
 		return 0;
 
-	if (dsth != NULL) {
+	if (dstg != NULL) {
 		assert(csch_obj_is_grp(dsth));
+		assert(dstg->extobj_inhibit >= 0);
+		dstg->extobj_inhibit++;
 	}
 
 	for(n = lht_dom_first(&it, subtree); n != NULL; n = lht_dom_next(&it))
 		csch_lht_parse_attribs_val(sheet, dstg, dsta, n->name, n, error, ectx, CSCH_ATP_USER_DEFAULT);
 
+	if (dstg != NULL) {
+		dstg->extobj_inhibit--;
+		assert(dstg->extobj_inhibit >= 0);
+	}
+
 	return 0;
 }
 
