@@ -40,6 +40,7 @@
 
 #include "act_idpath.c"
 #include "act_search.c"
+#include "act_rtree.c"
 
 static const char csch_acts_GetValue[] = "GetValue(input, units, relative, default_unit)";
 static const char csch_acth_GetValue[] = "Convert a coordinate value. Returns an unitless double or FGW_ERR_ARG_CONV. The 3rd parameter controls whether to require relative coordinates (+- prefix). Wraps rnd_get_value_ex().";
@@ -76,7 +77,8 @@ rnd_action_t act_read_action_list[] = {
 	{"SearchObjAt", csch_act_SearchObjAt, csch_acth_SearchObjAt, csch_acts_SearchObjAt},
 	{"SearchObjAtUnsel", csch_act_SearchObjAt, csch_acth_SearchObjAt, csch_acts_SearchObjAt},
 	{"SearchObjAtGuiInspect", csch_act_SearchObjAt, csch_acth_SearchObjAt, csch_acts_SearchObjAt},
-	{"SchGetXY", csch_act_SchGetXY, csch_acth_SchGetXY, csch_acts_SchGetXY}
+	{"SchGetXY", csch_act_SchGetXY, csch_acth_SchGetXY, csch_acts_SchGetXY},
+	{"RtreeList", csch_act_RtreeList, csch_acth_RtreeList, csch_acts_RtreeList}
 };
 
 static const char *act_read_cookie = "act_read";
