@@ -64,7 +64,7 @@ static sch_rnd_ba_t *ba_find_conn_del(sch_rnd_backann_t *ctx, const char *net, c
 	return NULL;
 }
 
-static void backann_postproc(sch_rnd_backann_t *ctx)
+void sch_rnd_backann_postproc(sch_rnd_backann_t *ctx)
 {
 	long n;
 	for(n = 0; n < ctx->list.used; n++) {
@@ -143,7 +143,7 @@ static int backann_parse(sch_rnd_backann_t *ctx)
 	if (err)
 		backann_free_list(ctx);
 	else
-		backann_postproc(ctx);
+		sch_rnd_backann_postproc(ctx);
 
 	return err;
 }
