@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - alternate function mapper
+ *  sch-rnd - modular/flexible schematics editor - alternate function mapper
  *  Copyright (C) 2023 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 Entrust Fund in 2023)
@@ -53,7 +53,7 @@ RND_INLINE int funcmap_fetch(csch_project_t *prj, const char *comp_name, csch_ac
 	if (abst == NULL)
 		return -1;
 
-	comp = csch_acomp_get(abst, comp_name, 0);
+	comp = csch_acomp_get(abst, comp_name);
 	if (comp == NULL)
 		return -1;
 
