@@ -1,8 +1,8 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - GUI
- *  Copyright (C) 2020 Tibor 'Igor2' Palinkas
+ *  sch-rnd - modular/flexible schematics editor - GUI
+ *  Copyright (C) 2020,2023 Tibor 'Igor2' Palinkas
  *  copied from pcb-rnd, interactive printed circuit board design
  *  Copyright (C) 2017..2019 Tibor 'Igor2' Palinkas
  *
@@ -36,16 +36,41 @@
 #include <librnd/core/rnd_conf.h>
 #include <librnd/hid/hid.h>
 #include <librnd/core/hidlib.h>
+#include <librnd/plugins/lib_hid_common/zoompan.h>
+
+#include <libcschem/concrete.h>
+#include <sch-rnd/select.h>
 
 #include "act.h"
 
-#define NOGUI() \
-do { \
-	if ((rnd_gui == NULL) || (!rnd_gui->gui)) { \
-		RND_ACT_IRES(1); \
-		return 0; \
-	} \
-	RND_ACT_IRES(0); \
-} while(0)
+const char csch_acts_Zoom_[] =
+	rnd_gui_acts_zoom
+	"Zoom(selected)\n";
+const char csch_acth_Zoom[] = "GUI zoom";
+/* DOC: zoom.html */
+fgw_error_t csch_act_Zoom(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	rnd_design_t *hidlib = RND_ACT_DESIGN;
+	csch_sheet_t *sheet = (csch_sheet_t *)hidlib;
+	const char *csch_acts_Zoom = csch_acts_Zoom_;
+	rnd_acts_Zoom = csch_acts_Zoom_;
 
+	RND_GUI_NOGUI();
 
+	if (argc == 2) {
+		const char *vp;
+
+		RND_ACT_CONVARG(1, FGW_STR, Zoom, vp = argv[1].val.str);
+
+		if (rnd_strcasecmp(vp, "selected") == 0) {
+			rnd_box_t sb;
+			if (sch_rnd_get_selection_bbox_gui(&sb, sheet) > 0)
+				rnd_gui->zoom_win(rnd_gui, sb.X1, sb.Y1, sb.X2, sb.Y2, 1);
+			else
+				rnd_message(RND_MSG_ERROR, "Can't zoom to selection: nothing selected\n");
+			return 0;
+		}
+	}
+
+	return rnd_gui_act_zoom(res, argc, argv);
+}
