@@ -1,10 +1,10 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - GUI
- *  Copyright (C) 2022,2023 Tibor 'Igor2' Palinkas
+ *  sch-rnd - modular/flexible schematics editor - GUI
+ *  Copyright (C) 2022,2023,2024 Tibor 'Igor2' Palinkas
  *
- *  (Supported by NLnet NGI0 PET Fund in 2022, Entrust in 2023)
+ *  (Supported by NLnet NGI0 PET Fund in 2022, Entrust in 2023,2024)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -41,11 +41,11 @@
 #include <librnd/core/actions.h>
 #include <librnd/core/event.h>
 #include <librnd/core/rnd_conf.h>
+#include <librnd/core/compat_fs.h>
 
 #include <libcschem/concrete.h>
 #include <libcschem/project.h>
 #include <libcschem/util_project.h>
-#include <libcschem/util_path.h>
 
 #include <sch-rnd/multi.h>
 
@@ -62,6 +62,7 @@ const char sheetsel_tooltip[] =
 	" [R] root sheet (directly compiled)\n"
 	" [a] aux sheet (referenced from hierarchy)\n"
 	" [u] unlisted sheet (in the same dir)\n"
+	" [E] external (unlisted, loaded for hierarchy)\n"
 	" [?] unknown/undecided sheet state\n";
 
 typedef struct sheetsel_ctx_s sheetsel_ctx_t;
@@ -80,6 +81,7 @@ static const char *sheet_marks(csch_project_t *prj, csch_sheet_t *sheet)
 		case CSCH_SHTY_AUX:      return " [a]";
 		case CSCH_SHTY_ROOT:     return " [R]";
 		case CSCH_SHTY_UNLISTED: return " [u]";
+		case CSCH_SHTY_EXTERNAL: return " [E]";
 	}
 	return " [??]";
 }
@@ -102,7 +104,7 @@ static void sheetsel_prj2dlg(sheetsel_ctx_t *ss)
 		csch_project_t *prj = e->value;
 		char *end;
 		gds_t tmp = {0};
-		const char *bn = csch_parent_dir_name(e->key);
+		const char *bn = rnd_parent_dir_name(e->key);
 
 		gds_append_str(&tmp, bn);
 		if (tmp.array != NULL) {
