@@ -1039,8 +1039,10 @@ static int altium_parse_net_labels(io_altium_rctx_t *rctx)
 			return -1;
 		}
 		if (name == NULL) {
-			error(rec, ("altium_parse_net_labels(): missing text field for net name\n"));
-			return -1;
+			error(rec, ("altium_parse_net_labels(): missing text field for net name - ignoring object\n(This was probably an invisible netname object in Protel)\n"));
+			/* Protel 99SE seems to produce net labels with no text; in the Protel
+			   GUI these are invisible objects with no effect. Reported by Scott */
+			continue;
 		}
 
 		x += xf / FRAC_DIV;
@@ -2209,7 +2211,7 @@ static void *altium_prealloc_pin(io_altium_rctx_t *rctx, altium_record_t *rec)
 	}
 
 	if (alti_slot_skip(parent, opartid, opartdsp))
-		return NOGRP;
+		return (void *)NOGRP;
 
 	/* orientation */
 	switch(cong & 0x03) {
