@@ -200,6 +200,7 @@ static int easypro_parse_pin(read_ctx_t *ctx, gdom_node_t *obj, csch_cgrp_t *par
 
 	/* figure rotation and direction */
 	switch((int)rot) {
+		case -1: /* null */
 		case 360:
 		case 0:   dx = +1; break;
 		case 90:  dy = +1; break;
@@ -291,6 +292,7 @@ static int easypro_parse_attr(read_ctx_t *ctx, gdom_node_t *obj, csch_cgrp_t **p
 		else if (vvis) txt->text = rnd_concat("%../a.", key, "%", NULL);
 
 		switch((int)rot) {
+			case -1: /* null */
 			case 360:
 			case 0: break;
 			case 90:
@@ -636,7 +638,7 @@ static int easypro_parse_text(read_ctx_t *ctx, gdom_node_t *obj, csch_cgrp_t *pa
 
 	roti = rot;
 	switch(roti) {
-		case 0: case 90: case 180: case 270: case 360: break;
+		case -1: case 0: case 90: case 180: case 270: case 360: break;
 		default:
 			error_at(ctx, obj, ("easypro_parse_text: invalid rotation angle %f\n", rot));
 			return -1;
@@ -745,28 +747,44 @@ static int easypro_parse_linestyle(read_ctx_t *ctx, gdom_node_t *obj, csch_cgrp_
    first one that has key Symbol; the value is the hash-like name of
    the symbol to use. This is useful when the COMPONENT line doesn't
    have a symbol name */
-static const char *easypro_find_synmanme(read_ctx_t *ctx, gdom_node_t *obj, long objidx)
+static const char *easypro_find_symname(read_ctx_t *ctx, gdom_node_t *obj, long objidx)
 {
 	gdom_node_t *parent = obj->parent, *attr, *key;
 	long n;
+	const char *device;
 
 	assert(parent->type == GDOM_ARRAY);
 
+	/* Look up Symbol and Device ATTRs; if Symbol is found, return that
+	   immediately. Otherwise if Device is found, do a lookup through the
+	   project file. If all else fails, return NULL */
 	for(n = objidx+1; n < parent->value.array.used; n++) {
 		attr = parent->value.array.child[n];
 		if ((attr->type != GDOM_ARRAY) || (attr->value.array.used < 1))
-			return NULL;
+			break;
 
 		key = attr->value.array.child[0];
 		if ((key->type == GDOM_STRING) && (strcmp(key->value.str, "COMPONENT") == 0))
-			return NULL;
+			break;
 
 		if ((key->type == GDOM_STRING) && (strcmp(key->value.str, "ATTR") == 0)) {
-			if ((attr->value.array.used >= 5) && (strcmp(attr->value.array.child[3]->value.str, "Symbol") == 0))
+			if ((attr->value.array.used >= 5) && (strcmp(attr->value.array.child[3]->value.str, "Symbol") == 0) && (attr->value.array.child[4]->type == GDOM_STRING) && (attr->value.array.child[4]->value.str != NULL) && (*attr->value.array.child[4]->value.str != '\0'))
 				return attr->value.array.child[4]->value.str;
+			if ((attr->value.array.used >= 5) && (strcmp(attr->value.array.child[3]->value.str, "Device") == 0) && (attr->value.array.child[4]->type == GDOM_STRING))
+				device = attr->value.array.child[4]->value.str;
 		}
 	}
 
+	if (device != NULL) {
+		const char *symname;
+
+		/* Device ATTR is set, look up via the project file */
+		symname = htss_get(ctx->pro_devmap, device);
+		if (symname == NULL)
+			error_at(ctx, obj, ("easypro_find_symname: component references device '%s' that is not found in the devmap (in project.json) or has no symbol attribute\n", device));
+		return symname;
+	}
+
 	return NULL;
 }
 
@@ -796,7 +814,7 @@ static int easypro_parse_component(read_ctx_t *ctx, gdom_node_t *obj, long objid
 	/* if the COMPONENT line doesn't specify a symbol name, pick it out from
 	   the hash-like name from Symbol ATTR following the COMPONENT */
 	if ((symname == NULL) || (*symname == '\0')) {
-		symname = easypro_find_synmanme(ctx, obj, objidx);
+		symname = easypro_find_symname(ctx, obj, objidx);
 		if (symname == NULL) {
 			error_at(ctx, obj, ("easypro_parse_component: failed to find symbol name from ATTR\n"));
 			return -1;
@@ -854,6 +872,190 @@ static int easypro_parse_wire(read_ctx_t *ctx, gdom_node_t *obj, csch_cgrp_t *pa
 	return 0;
 }
 
+static void easypro_warn_bus(read_ctx_t *ctx)
+{
+	if (ctx->warned_bus)
+		return;
+
+	ctx->warned_bus = 1;
+	rnd_message(RND_MSG_ERROR, "io_easyeda: buses are loaded as purely graphical features for now; expect broken netlist output\n");
+}
+
+/* "BUS","e1994",[[535,755,485,755],[485,755,485,735]],"st8",0]
+     kw    id     x1   y1  x2  y2                       sty  ?  */
+static int easypro_parse_bus(read_ctx_t *ctx, gdom_node_t *obj, csch_cgrp_t *parent)
+{
+	gdom_node_t *segs, *coords;
+	long n;
+
+	REQ_ARGC_GTE(obj, 5, "easypro_parse_bus", return -1);
+	GET_ARG_ARRAY(segs, obj, 2, "easypro_parse_bus: segments", return -1);
+
+	easypro_warn_bus(ctx);
+
+	for(n = 0; n < segs->value.array.used; n++) {
+		double x1, y1, x2, y2;
+
+		GET_ARG_ARRAY(coords, segs, n, "easypro_parse_bus: coords", return -1);
+		REQ_ARGC_GTE(coords, 4, "easypro_parse_bus coords", return -1);
+
+		GET_ARG_DBL(x1,   coords, 0,   "easypro_parse_bus: coord x1", return -1);
+		GET_ARG_DBL(y1,   coords, 1,   "easypro_parse_bus: coord y1", return -1);
+		GET_ARG_DBL(x2,   coords, 2,   "easypro_parse_bus: coord x2", return -1);
+		GET_ARG_DBL(y2,   coords, 3,   "easypro_parse_bus: coord y2", return -1);
+
+		csch_alien_mkline(&ctx->alien, &ctx->sheet->direct, x1, y1, x2, y2, "bus");
+	}
+
+	return 0;
+}
+
+/* "BUSENTRY","e2114","e1994",   0  ,475,755,0]
+     kw        id       id       idx  x   y  ? */
+static int easypro_parse_busentry(read_ctx_t *ctx, gdom_node_t *obj, csch_cgrp_t *parent)
+{
+	double idx, x, y;
+
+	REQ_ARGC_GTE(obj, 7, "easypro_parse_busentry", return -1);
+	GET_ARG_DBL(idx, obj, 3,   "easypro_parse_busentry: index", return -1);
+	GET_ARG_DBL(x,   obj, 4,   "easypro_parse_busentry: coord x", return -1);
+	GET_ARG_DBL(y,   obj, 5,   "easypro_parse_busentry: coord y", return -1);
+
+	easypro_warn_bus(ctx);
+
+	csch_alien_mkline(&ctx->alien, &ctx->sheet->direct, x, y, x+10, y, "busterm-primary");
+
+	return 0;
+}
+
+typedef struct easypro_tab_s {
+	vtd0_t rowy, colx; /* top left coords of each cell; both arrays are one element longer than the original table so the width/height of the last cell can be computed */
+} easypro_tab_t;
+
+static void easypro_tab_free(easypro_tab_t *tab)
+{
+	vtd0_uninit(&tab->rowy);
+	vtd0_uninit(&tab->colx);
+	free(tab);
+}
+
+/* "TABLE","e4459",  25,334,  [22,22,22,22,22],[200,42.8,42.8],[0,0,0,0,0],[0,0,0]
+     kw        id    top x;y    row heights      col widths */
+static int easypro_parse_table(read_ctx_t *ctx, gdom_node_t *obj, csch_cgrp_t *parent)
+{
+	double x, y, x2, y2, crd;
+	const char *id;
+	long n;
+	int res = 0;
+	gdom_node_t *rowhs, *colws;
+	easypro_tab_t *tab;
+
+	REQ_ARGC_GTE(obj, 8,          "easypro_parse_table", return -1);
+	GET_ARG_STR(id, obj, 1,       "easypro_parse_table: id", return -1);
+	GET_ARG_DBL(x, obj, 2,        "easypro_parse_table: x", return -1);
+	GET_ARG_DBL(y, obj, 3,        "easypro_parse_table: y", return -1);
+	GET_ARG_ARRAY(rowhs, obj, 4,  "easypro_parse_table: row heights", return -1);
+	GET_ARG_ARRAY(colws, obj, 5, "easypro_parse_table: col widths", return -1);
+
+
+	tab = calloc(sizeof(easypro_tab_t), 1);
+
+	for(n = 0, crd = y; n < rowhs->value.array.used; n++) {
+		double h;
+		GET_ARG_DBL(h,    rowhs, n,   "easypro_parse_table: row height", res = -1;continue);
+		vtd0_append(&tab->rowy, crd);
+		crd -= h;
+	}
+	y2 = crd;
+	vtd0_append(&tab->rowy, crd);
+
+	for(n = 0, crd = x; n < colws->value.array.used; n++) {
+		double w;
+		GET_ARG_DBL(w,    colws, n,   "easypro_parse_table: col width", res = -1;continue);
+		vtd0_append(&tab->colx, crd);
+		crd += w;
+	}
+	x2 = crd;
+	vtd0_append(&tab->colx, crd);
+
+	if (ctx->pro_tabtab == NULL)
+		ctx->pro_tabtab = htsp_alloc(strhash, strkeyeq);
+
+	htsp_insert(ctx->pro_tabtab, rnd_strdup(id), tab);
+
+	/* draw outer frame */
+	csch_alien_mkline(&ctx->alien, &ctx->sheet->direct, x, y, x2, y, "sheet-decor");
+	csch_alien_mkline(&ctx->alien, &ctx->sheet->direct, x2, y, x2, y2, "sheet-decor");
+	csch_alien_mkline(&ctx->alien, &ctx->sheet->direct, x, y, x, y2, "sheet-decor");
+	csch_alien_mkline(&ctx->alien, &ctx->sheet->direct, x, y2, x2, y2, "sheet-decor");
+
+	return res;
+}
+
+/* "TABEL_CELL", "e17781","e4459", "GD32F407Vx",  2,   0,   1,        1,          "st21","st21","st21","st21","st22",null]
+     kw          id       tbl_id    text          row  col  rowspan   colspan                                              
+   Note: the keyword has a typo in it */
+static int easypro_parse_table_cell(read_ctx_t *ctx, gdom_node_t *obj, csch_cgrp_t *parent)
+{
+	const char *tid, *text;
+	double row, col, rowspan, colspan, x1, y1, x2, y2, tx, ty;
+	easypro_tab_t *tab;
+	csch_text_t *txt;
+
+	REQ_ARGC_GTE(obj, 8,          "easypro_parse_table_cell", return -1);
+	GET_ARG_STR(tid, obj, 2,      "easypro_parse_table_cell: id", return -1);
+	GET_ARG_STR(text, obj, 3,     "easypro_parse_table_cell: id", return -1);
+	GET_ARG_DBL(row, obj, 4,      "easypro_parse_table_cell: row", return -1);
+	GET_ARG_DBL(col, obj, 5,      "easypro_parse_table_cell: col", return -1);
+	GET_ARG_DBL(rowspan, obj, 6,  "easypro_parse_table_cell: rowspan", return -1);
+	GET_ARG_DBL(colspan, obj, 7,  "easypro_parse_table_cell: colspan", return -1);
+
+	if (ctx->pro_tabtab == NULL) {
+		error_at(ctx, obj, ("table_cell without table\n"));
+		return -1;
+	}
+
+	if ((colspan < 1) || (rowspan < 1) || (*text == '\0'))
+		return 0;
+
+
+	tab = htsp_get(ctx->pro_tabtab, rnd_strdup(tid));
+	if (tab == NULL) {
+		error_at(ctx, obj, ("table_cell referencing table '%s' which is not created\n", tid));
+		return -1;
+	}
+
+	if ((row < 0) || (row+rowspan > tab->rowy.used)) {
+		error_at(ctx, obj, ("table_cell row is out of bounds: %f..%f in a table with %ld rows\n", row, row+rowspan, tab->rowy.used-1));
+		return -1;
+	}
+
+	if ((col < 0) || (col+colspan > tab->colx.used)) {
+		error_at(ctx, obj, ("table_cell col is out of bounds: %f..%f in a table with %ld cols\n", col, col+colspan, tab->colx.used-1));
+		return -1;
+	}
+
+	x1 = tab->colx.array[(long)col];
+	x2 = tab->colx.array[(long)(col+colspan)];
+	y1 = tab->rowy.array[(long)row];
+	y2 = tab->rowy.array[(long)(row+rowspan)];
+
+	if (row > 0)
+		csch_alien_mkline(&ctx->alien, &ctx->sheet->direct, x1, y1, x2, y1, "sheet-decor");
+	if (col > 0)
+		csch_alien_mkline(&ctx->alien, &ctx->sheet->direct, x1, y1, x1, y2, "sheet-decor");
+
+	tx = x1;
+	ty = tab->rowy.array[(long)row+1];
+
+	txt = (csch_text_t *)csch_alien_mktext(&ctx->alien, &ctx->sheet->direct, tx, ty, "sheet-decor");
+	txt->text = rnd_strdup(text);
+
+	return 0;
+}
+
+
+
 /* object dispatcher */
 static int easypro_parse_any_obj(read_ctx_t *ctx, gdom_node_t *obj, long objidx, csch_cgrp_t **parent)
 {
@@ -880,7 +1082,10 @@ static int easypro_parse_any_obj(read_ctx_t *ctx, gdom_node_t *obj, long objidx,
 		case easy_LINESTYLE: return easypro_parse_linestyle(ctx, obj, *parent);
 		case easy_COMPONENT: return easypro_parse_component(ctx, obj, objidx, *parent);
 		case easy_WIRE: return easypro_parse_wire(ctx, obj, *parent);
-
+		case easy_BUS: return easypro_parse_bus(ctx, obj, *parent);
+		case easy_BUSENTRY: return easypro_parse_busentry(ctx, obj, *parent);
+		case easy_TABLE: return easypro_parse_table(ctx, obj, *parent);
+		case easy_TABEL_CELL: return easypro_parse_table_cell(ctx, obj, *parent); /* the keyword has a typo in it */
 		case easy_FONTSTYLE: return 0; /* ignore: sch-rnd uses pens */
 
 		case -1:
@@ -953,6 +1158,18 @@ static void easypro_uninit_ctx(read_ctx_t *ctx)
 		free(e->key);
 	htsi_uninit(&ctx->pro_pen_fill);
 
+	TODO("uninit pro_symtab");
+
+	if (ctx->pro_tabtab != NULL) {
+		htsp_entry_t *e;
+		for(e = htsp_first(ctx->pro_tabtab); e != NULL; e = htsp_next(ctx->pro_tabtab, e)) {
+			easypro_tab_free(e->value);
+			free(e->key);
+		}
+		htsp_uninit(ctx->pro_tabtab);
+		free(ctx->pro_tabtab);
+	}
+
 	ctx->alien.flip_y = 1;
 }
 
