@@ -64,7 +64,7 @@ extern conf_io_eeschema_t io_eeschema_conf;
 
 #include "read.h"
 
-#define dbg_printf rnd_trace
+/*#define dbg_printf rnd_trace*/
 
 #ifndef dbg_printf
 #define dbg_printf nope_printf
@@ -107,6 +107,7 @@ typedef struct read_ctx_s {
 	struct cache_sym_s* cur_libsym0; /* unit of the current libsym */
 	csch_cgrp_t* cur_sym;
 	csch_coord_t cur_sym_x, cur_sym_y; /* in sch-rnd coord */
+	int cur_sym_rot;
 	unsigned cur_sym_mirx : 1;
 	unsigned cur_sym_miry : 1;
 	unsigned cur_sym_exclude_from_sim : 1; /* set to 1 if schsym had this */
@@ -400,6 +401,36 @@ static char* eeschema_make_symname(read_ctx_t* const ctx,
 	return name;
 }
 
+static char* eeschema_make_symname2(read_ctx_t* const ctx,
+	gsxl_node_t* const src_node,
+	const char* lib_name_src, const char* const unit)
+{
+	/* lib_name = "GND_3" */
+	/* unit = "1" */
+
+	const size_t len_name = strlen(lib_name_src);
+	const size_t len_unit = strlen(unit);
+
+	char* const name = (char*)malloc(len_name + len_unit + 2);
+	char* str;
+
+	if(!name)
+	{
+		eechema_error(ctx, src_node, "could not allocate sym name");
+		return NULL;
+	}
+
+	str = name;
+
+	strcpy(str, lib_name_src);
+	str += len_name;
+	*str++ = ':';
+
+	strcpy(str, unit);
+
+	return name;
+}
+
 static int io_eeschema_postproc(read_ctx_t *ctx)
 {
 /* enable this if your format has an automatic text rotation so that
@@ -554,6 +585,13 @@ static int eechema_parse_yesno(read_ctx_t* const ctx, gsxl_node_t* node)
 			return 0;
 		}
 	}
+	else
+	if(node==NULL)
+	{
+		/* if this is NULL, it means parent has no children, thus */
+		/* implicitly "yes" */
+		return 1;
+	}
 
 	eechema_error(ctx, node, "invalid yes-no info");
 	return -1;
