@@ -29,7 +29,7 @@
 
 static int eeschema_parse_property__impl(read_ctx_t* const ctx,
 	csch_cgrp_t* const libsym, csch_cgrp_t* const symref,
-	gsxl_node_t* const src_node, int force_place);
+	gsxl_node_t* const src_node, int parent_rot, int force_place);
 
 static int eechema_parse__ignore(read_ctx_t* ctx, csch_cgrp_t* dst,
 	gsxl_node_t* node)
@@ -53,6 +53,7 @@ static int eechema_parse__sch_version(read_ctx_t* ctx, csch_cgrp_t* dst,
 	gsxl_node_t* node)
 {
 	static const int min_ver = 20211123;
+	static const int max_ver = 20250114;
 	TODO("Adjust version requirement");
 
 	if(node!=NULL && node->str!=NULL)
@@ -74,6 +75,14 @@ static int eechema_parse__sch_version(read_ctx_t* ctx, csch_cgrp_t* dst,
 			return -1;
 		}
 
+		if(ctx->ver>max_ver)
+		{
+			rnd_message(RND_MSG_WARNING, "%s:%ld:%ld: eeschema schematics "
+				"file is newer than this plugin was designed for, "
+				"you may experience glitches, please report them\n",
+				ctx->fn, 1+(long)node->line, 1+(long)node->col);
+		}
+
 		return attach_attrib(ctx, &ctx->sheet->direct, node->parent,
 			node->parent->str, node->str);
 	}
@@ -93,7 +102,7 @@ static int eechema_parse__sch_uuid(read_ctx_t* ctx, csch_cgrp_t* dst,
 	gsxl_node_t* node)
 {
 	return attach_attrib(ctx, &ctx->sheet->direct, node->parent,
-		"kicad/uuid", node->str);
+		"-kicad/uuid", node->str);
 }
 
 static int eechema_parse__sch_attach_attr2(read_ctx_t* ctx, csch_cgrp_t* dst,
@@ -195,11 +204,12 @@ static cache_sym_t* eeschema_dup_libsym(read_ctx_t* const ctx,
 		return NULL;
 	}
 
-	if(htsp_get(&ctx->syms, name)!=NULL)
+	cs = (cache_sym_t*)htsp_get(&ctx->syms, name);
+
+	/* merge libsym data together */
+	if(cs)
 	{
-		eechema_error(ctx, node, "duplicate library symbol: '%s'", name);
-		free(name);
-		return NULL;
+		return cs;
 	}
 
 	cs = (cache_sym_t*)calloc(1, sizeof(cache_sym_t));
@@ -418,6 +428,7 @@ static int eechema_parse__sch_symbol(read_ctx_t* ctx, csch_cgrp_t* dst,
 	gsxl_node_t* node)
 {
 	gsxl_node_t* lib_id = NULL;
+	gsxl_node_t* lib_name = NULL;
 	gsxl_node_t* at = NULL;
 	gsxl_node_t* unit = NULL;
 	gsxl_node_t* uuid = NULL;
@@ -438,6 +449,11 @@ static int eechema_parse__sch_symbol(read_ctx_t* ctx, csch_cgrp_t* dst,
 			lib_id = node->children;
 		}
 		else
+		if(strcmp(node->str, "lib_name")==0)
+		{
+			lib_name = node->children;
+		}
+		else
 		if(strcmp(node->str, "unit")==0)
 		{
 			unit = node->children;
@@ -466,11 +482,22 @@ static int eechema_parse__sch_symbol(read_ctx_t* ctx, csch_cgrp_t* dst,
 	}
 
 	{
-		char* const name = eeschema_make_symname(ctx, parent, lib_id->str,
-			unit->str);
+		char* name;
+
+		if(lib_name==NULL)
+		{
+			name = eeschema_make_symname(ctx, parent, lib_id->str, unit->str);
+		}
+		else
+		{
+			name = eeschema_make_symname2(ctx, parent, lib_name->str,
+				unit->str);
+		}
 
 		if(!name) { return -1; }
 
+		dbg_printf("  sym lookup: \"%s\"\n", name);
+
 		cs = htsp_get(&ctx->syms, name);
 
 		free(name);
@@ -502,6 +529,7 @@ static int eechema_parse__sch_symbol(read_ctx_t* ctx, csch_cgrp_t* dst,
 	ctx->cur_sym_x = csch_alien_coord_x(&ctx->alien, x);
 	ctx->cur_sym_y = csch_alien_coord_y(&ctx->alien, y);
 
+	ctx->cur_sym_rot              = rot;
 	ctx->cur_sym_mirx             = 0;
 	ctx->cur_sym_miry             = 0;
 	ctx->cur_sym_exclude_from_sim = 0;
@@ -545,7 +573,7 @@ static int eechema_parse__sch_symbol(read_ctx_t* ctx, csch_cgrp_t* dst,
 
 	if(res==0 && uuid!=NULL)
 	{
-		res = attach_attrib(ctx, sym, uuid, "kicad/uuid", uuid->str);
+		res = attach_attrib(ctx, sym, uuid, "-kicad/uuid", uuid->str);
 	}
 
 	/* post-proc */
@@ -625,7 +653,74 @@ static int eechema_parse__sch_bus(read_ctx_t* ctx, csch_cgrp_t* dst,
 		return -1;
 	}
 
-	return eeschema_render_wires(ctx, &ctx->sheet->direct, parent, pts);
+	if(!eeschema_render_polyline(ctx, &ctx->sheet->direct, parent, pts, "bus",
+		NULL, 0, 0, 0, 0))
+	{
+		return -1;
+	}
+
+	return 0;
+}
+
+static int eechema_parse_busentry(read_ctx_t* ctx, csch_cgrp_t* dst,
+	gsxl_node_t* node)
+{
+	gsxl_node_t* at = NULL;
+	gsxl_node_t* size = NULL;
+
+	gsxl_node_t* const parent = node->parent;
+
+	float x, y;
+	float sx, sy;
+
+	for(;node;node=node->next)
+	{
+		if(strcmp(node->str, "at")==0)
+		{
+			at = node->children;
+		}
+		else
+		if(strcmp(node->str, "size")==0)
+		{
+			size = node->children;
+		}
+		else
+		if(strcmp(node->str, "stroke")==0 ||
+			strcmp(node->str, "uuid")==0)
+		{
+			/* ignore these */
+		}
+		else
+		{
+			unexpected_child(ctx, node->parent, node);
+			return -1;
+		}
+	}
+
+	if(!at)
+	{
+		eechema_error(ctx, parent, "missing 'at' data from 'bus_entry' object");
+		return -1;
+	}
+
+	if(!size)
+	{
+		eechema_error(ctx, parent, "missing 'size' data from 'bus_entry' object");
+		return -1;
+	}
+
+	if(eechema_parse_xy(ctx, at, &x, &y)!=0)
+	{
+		return -1;
+	}
+
+	if(eechema_parse_xy(ctx, size, &sx, &sy)!=0)
+	{
+		return -1;
+	}
+
+	return eeschema_render_busentry_decor(ctx, dst, parent, x, y, sx, sy,
+		"busterm-primary");
 }
 
 static int eechema_parse_polyline(read_ctx_t* ctx, csch_cgrp_t* dst,
@@ -1330,7 +1425,7 @@ static int eechema_parse_X_label(read_ctx_t* const ctx,
 			if(strcmp(n->str, "property")==0)
 			{
 				if(eeschema_parse_property__impl(ctx, label, NULL,
-					n->children, 1)!=0)
+					n->children, rot, 1)!=0)
 				{
 					return -1;
 				}
@@ -1445,17 +1540,6 @@ static int eechema_parse_netclassflag(read_ctx_t* ctx, csch_cgrp_t* dst,
 		return -1;
 	}
 
-	{
-		csch_source_arg_t* const src = make_src_attrib(ctx, node);
-
-		if(!csch_alien_mkpin_line(&ctx->alien, src, grp, x, y, x, y))
-		{
-			eechema_error(ctx, node->parent,
-				"could not create 'netclass_flag' pin line");
-			return -1;
-		}
-	}
-
 	/* process (property) nodes */
 	{
 		gsxl_node_t* n = node;
@@ -1465,7 +1549,7 @@ static int eechema_parse_netclassflag(read_ctx_t* ctx, csch_cgrp_t* dst,
 			if(strcmp(n->str, "property")==0)
 			{
 				if(eeschema_parse_property__impl(ctx, grp, NULL,
-					n->children, 1)!=0)
+					n->children, rot, 1)!=0)
 				{
 					return -1;
 				}
@@ -1659,7 +1743,7 @@ static int eechema_parse__sch_sheet(read_ctx_t* ctx, csch_cgrp_t* dst,
 			if(strcmp(n->str, "property")==0)
 			{
 				if(eeschema_parse_property__impl(ctx, grp, NULL,
-					n->children, 1)!=0)
+					n->children, 0, 1)!=0)
 				{
 					return -1;
 				}
@@ -1873,7 +1957,7 @@ static int eechema_parse__libsym_symbol(read_ctx_t* ctx,
 
 static int eeschema_parse_property__impl(read_ctx_t* const ctx,
 	csch_cgrp_t* const libsym, csch_cgrp_t* const symref,
-	gsxl_node_t* const src_node, int force_place)
+	gsxl_node_t* const src_node, int parent_rot, int force_place)
 {
 	const char* key;
 	const char* value;
@@ -2118,6 +2202,35 @@ static int eeschema_parse_property__impl(read_ctx_t* const ctx,
 			dy = csch_alien_coord_y(&ctx->alien, y) - t->spec1.y;
 		}
 
+		/* rotate floater back to compansate parent rotation */
+		switch(parent_rot)
+		{
+		case 0:
+			break;
+		case 90:
+			{ csch_coord_t t = dx; dx = dy; dy = -t; }
+			if(rot==90) { dx -= bbh; }
+			break;
+		case 180:
+			dy = -dy;
+			if(rot==0) { dy += bbh; dx -= bbw; }
+			if(rot==90) { dx -= 2*bbh; }
+			break;
+		case 270:
+			{ csch_coord_t t = dx; dx = -dy; dy = t; }
+			if(rot==0) { dy += bbh; }
+			break;
+		}
+
+		dbg_printf("  justify BB={%u,%u}, d={%i,%i}, rot=%i(+%i)\n",
+			(unsigned int)bbw, (unsigned int)bbh,
+			(int)dx, (int)dy, (int)rot, (int)parent_rot);
+
+		if(180<=((rot+parent_rot)%360))
+		{
+			rot = (rot + 180) % 360;
+		}
+
 		if(eeschema_justify_text(ctx, justify, bbw, bbh, rot, &dx, &dy,
 			&mirx, &miry))
 		{
@@ -2128,6 +2241,9 @@ static int eeschema_parse_property__impl(read_ctx_t* const ctx,
 		{
 			eeschema_sym_child_moverotmir(ctx, symref, (csch_chdr_t*)t,
 				dx, dy, rot, mirx, miry);
+
+			dbg_printf("  moverotmir: dx=%i, dy=%i, rot=%i, mir=%i/%i\n",
+				(int)dx, (int)dy, (int)rot, (int)mirx, (int)miry);
 		}
 		else
 		{
@@ -2151,7 +2267,7 @@ static int eeschema_parse_property__impl(read_ctx_t* const ctx,
 static int eechema_parse__libsym_property(read_ctx_t* ctx,
 	csch_cgrp_t* dst, gsxl_node_t* node)
 {
-	return eeschema_parse_property__impl(ctx, dst, NULL, node, 0);
+	return eeschema_parse_property__impl(ctx, dst, NULL, node, 0, 0);
 }
 
 static int eechema_parse__libsymdata_pin(read_ctx_t* ctx,
@@ -2218,6 +2334,11 @@ static int eechema_parse__libsymdata_pin(read_ctx_t* ctx,
 			return 0;
 		}
 		else
+		if(strcmp(node->str, "alternate")==0)
+		{
+			TODO("what alternate is used for?");
+		}
+		else
 		{
 			unexpected_child(ctx, parent, node);
 			return -1;
@@ -2489,7 +2610,8 @@ static int eechema_parse__schsym_property(read_ctx_t* ctx,
 {
 	csch_cgrp_t* const libsym = ctx->cur_sym->data.ref.grp;
 
-	if(eeschema_parse_property__impl(ctx, libsym, ctx->cur_sym, node, 0)!=0)
+	if(eeschema_parse_property__impl(ctx, libsym, ctx->cur_sym, node,
+		ctx->cur_sym_rot, 0)!=0)
 	{
 		return -1;
 	}
@@ -3052,8 +3174,10 @@ static const dispatch_t eechema_disptab_sch[] =
 	{ "global_label", eechema_parse_globallabel },
 	{ "hierarchical_label", eechema_parse_hierarchicallabel },
 	{ "netclass_flag", eechema_parse_netclassflag },
-	{ "bus_entry", eechema_parse__ignore }, /* TODO: bus is not supported, these must be ignored */
+	{ "bus_entry", eechema_parse_busentry },
+	{ "bus_alias", eechema_parse__ignore }, /* TODO */
 	{ "sheet", eechema_parse__sch_sheet },
+	{ "embedded_fonts", eechema_parse__ignore }, /* TODO: what's the purpose of this? */
 	DRAWING_PRIMITIVES
 	{ 0 }
 };
@@ -3068,6 +3192,7 @@ static const dispatch_t eechema_disptab_libsym0[] =
 	{ "on_board", eechema_parse__libsym_on_board },
 	{ "property", eechema_parse__libsym_property },
 	{ "power", eechema_parse__ignore },
+	{ "embedded_fonts", eechema_parse__ignore }, /* TODO: what's the purpose of this? */
 
 	{ "symbol", eechema_parse__ignore_silent },
 	{ 0 }
@@ -3085,6 +3210,7 @@ static const dispatch_t eechema_disptab_libsym1[] =
 	{ "on_board", eechema_parse__ignore_silent },
 	{ "property", eechema_parse__ignore_silent },
 	{ "power", eechema_parse__ignore_silent },
+	{ "embedded_fonts", eechema_parse__ignore_silent },
 	{ 0 }
 };
 
@@ -3110,6 +3236,7 @@ static const dispatch_t eechema_disptab_titleblock[] =
 static const dispatch_t eechema_disptab_schsymdata[] =
 {
 	{ "lib_id", eechema_parse__ignore_silent }, /* already processed! */
+	{ "lib_name", eechema_parse__ignore_silent }, /* already processed! */
 	{ "at", eechema_parse__ignore_silent }, /* already processed! */
 	{ "mirror", eechema_parse__schsym_mirror },
 	{ "unit", eechema_parse__ignore_silent }, /* already processed! */
