@@ -270,6 +270,41 @@ static int eeschema_solve_circle_eq(read_ctx_t* const ctx,
 	return 0;
 }
 
+static int render_arc_segment(read_ctx_t* const ctx, csch_chdr_t* const arc,
+	const float cx, const float cy, const float r, float start, float end)
+{
+	float delta = end - start;
+
+/*
+	if(delta<0.0)
+	{
+		float t = start;
+		start = end;
+		end = t;
+		delta = -delta;
+	}
+*/
+
+	if(delta>180.0)
+	{
+		dbg_printf("  MORE\n");
+		delta -= 360.0;
+	}
+	else
+	if(delta<(-180.0))
+	{
+		dbg_printf("  LESS\n");
+		delta += 360.0;
+		/*delta = 360.0 + delta;*/
+	}
+
+	dbg_printf("  add segment: start=%f, delta=%f\n", start, delta);
+
+	csch_alien_append_poly_arc(&ctx->alien, arc, cx, cy, r, start, delta);
+
+	return 0;
+}
+
 static csch_chdr_t* eeschema_render_arc(read_ctx_t* const ctx,
 	csch_cgrp_t* const dst, gsxl_node_t* const objroot,
 	gsxl_node_t* const start, gsxl_node_t* const mid, gsxl_node_t* const end,
@@ -284,6 +319,7 @@ static csch_chdr_t* eeschema_render_arc(read_ctx_t* const ctx,
 	float r;
 	float ang_start;
 	float ang_end;
+	float ang_mid;
 	float ang_delta;
 
 	if(eechema_parse_xy(ctx, start, &sx, &sy)!=0 ||
@@ -307,23 +343,27 @@ static csch_chdr_t* eeschema_render_arc(read_ctx_t* const ctx,
 		return NULL;
 	}
 
-	ang_start = -atan2(sy-cy, sx-cx) * 180.0 / M_PI;
-	ang_end   = -atan2(ey-cy, ex-cx) * 180.0 / M_PI;
+	dbg_printf("  solution: c=(%f;%f), r=%f\n", cx, cy, r);
+
+	ang_start = atan2(cy-sy, sx-cx) * 180.0 / M_PI;
+	ang_mid   = atan2(cy-my, mx-cx) * 180.0 / M_PI;
+	ang_end   = atan2(cy-ey, ex-cx) * 180.0 / M_PI;
 
 	if(ctx->cur_libsym)
 	{
 		/* if rendering into a symbol, Y increases downwards, messing up */
 		/* the computation above, so just hack it */
-		ang_start += 180;
-		ang_end   += 180;
+		ang_start = -ang_start;
+		ang_mid   = -ang_mid;
+		ang_end   = -ang_end;
 	}
 
 	if(ang_start<0) { ang_start += 360.0; }
+	if(ang_mid<0) { ang_mid += 360.0; }
 	if(ang_end<0) { ang_end += 360.0; }
 
-	ang_delta = ang_start - ang_end;
-
-	if(ang_delta<0) { ang_delta += 360.0; }
+	dbg_printf("  angles: start=%f, mid=%f, end=%f\n", ang_start, ang_mid,
+		ang_end);
 
 	if(!(arc=csch_alien_mkpoly(&ctx->alien, dst, stroke, fill)))
 	{
@@ -331,53 +371,20 @@ static csch_chdr_t* eeschema_render_arc(read_ctx_t* const ctx,
 		return NULL;
 	}
 
-	/* ang_end is actually the start angle, because the points are in CW */
-	/* order, but angles increasing in CCW order */
-	/* (split arc up to avoid special cases!) */
-
-	if(ang_delta>240)
+	if(render_arc_segment(ctx, arc, cx, cy, r, ang_start, ang_mid)!=0)
 	{
-		float third = ang_delta * 0.3334;
-
-		dbg_printf("  3 segments: start=%f, delta1=%f(x2), delta2=%f\n",
-			ang_end, third, ang_delta-third*2);
-
-		csch_alien_append_poly_arc(&ctx->alien, arc, cx, cy, r, ang_end,
-			third);
-		ang_end += third;
-
-		csch_alien_append_poly_arc(&ctx->alien, arc, cx, cy, r, ang_end,
-			third);
-		ang_end += third;
-
-		csch_alien_append_poly_arc(&ctx->alien, arc, cx, cy, r, ang_end,
-			ang_delta-third*2);
+		return NULL;
 	}
-	else
-	if(ang_delta>120)
+
+	if(render_arc_segment(ctx, arc, cx, cy, r, ang_mid, ang_end)!=0)
 	{
-		float half = ang_delta * 0.5;
-
-		dbg_printf("  2 segments: start=%f, delta1=%f, delta2=%f\n", ang_end,
-			half, ang_delta-half);
-
-		csch_alien_append_poly_arc(&ctx->alien, arc, cx, cy, r, ang_end,
-			half);
-
-		csch_alien_append_poly_arc(&ctx->alien, arc, cx, cy, r, ang_end+half,
-			ang_delta-half);
-	}
-	else
-	{
-		dbg_printf("  1 segment: start=%f, delta=%f\n", ang_end, ang_delta);
-		csch_alien_append_poly_arc(&ctx->alien, arc, cx, cy, r, ang_end,
-			ang_delta);
+		return NULL;
 	}
 
 	if(fill)
 	{
-		csch_alien_append_poly_line(&ctx->alien, arc, sx, sy, cx, cy);
-		csch_alien_append_poly_line(&ctx->alien, arc, cx, cy, ex, ey);
+		csch_alien_append_poly_line(&ctx->alien, arc, ex, ey, cx, cy);
+		csch_alien_append_poly_line(&ctx->alien, arc, cx, cy, sx, sy);
 	}
 
 	return arc;
@@ -1041,3 +1048,17 @@ static int eeschema_render_netclass_decor(read_ctx_t* const ctx,
 
 	return 0;
 }
+
+static int eeschema_render_busentry_decor(read_ctx_t* const ctx,
+	csch_cgrp_t* const dst, gsxl_node_t* const objroot,
+	const float x, const float y, const float size_x, const float size_y,
+	const char* const stroke)
+{
+	if(!csch_alien_mkline(&ctx->alien, dst, x, y, x+size_x, y+size_y, stroke))
+	{
+		eechema_error(ctx, objroot, "could not make bus_entry decor line");
+		return -1;
+	}
+
+	return 0;
+}
