@@ -876,8 +876,10 @@ static csch_text_t *grp_ref_attr_text(read_ctx_t *ctx, csch_cgrp_t *rgrp, const
 		}
 	}
 
-	if (!alloc)
+	if (!alloc) {
+		free(tmp);
 		return NULL;
+	}
 
 	/* not found, need to create */
 	isref = (strcmp(sdesc, "Ref") == 0);
