@@ -61,7 +61,7 @@ RND_INLINE double csch_alien_chk_range(csch_alien_read_ctx_t *ctx, double crd)
 
 	if ((crd > RMAX) || (crd < RMIN)) {
 		if (!ctx->warned_coord_range) {
-			rnd_message(RND_MSG_ERROR, "Drawing has coordinates too large. Try recompiling librnd for 64 bit coords.\n");
+			rnd_message(RND_MSG_ERROR, "Alien drawing has coordinates too large. Consider recompiling librnd for 64 bit coords.\n");
 			ctx->warned_coord_range = 1;
 		}
 	}
