@@ -73,6 +73,10 @@ void csch_alien_append_poly_line(csch_alien_read_ctx_t *ctx, csch_chdr_t *poly,
 void csch_alien_append_poly_arc(csch_alien_read_ctx_t *ctx, csch_chdr_t *poly_, double cx, double cy, double r, double sa, double da);
 void csch_alien_append_poly_bezier(csch_alien_read_ctx_t *ctx, csch_chdr_t *poly_, double x1, double y1, double x2, double y2, double x3, double y3, double x4, double y4);
 
+/* convenience composite: create a circle (really a polygon with arcs) */
+csch_chdr_t *csch_alien_mkcircle(csch_alien_read_ctx_t *ctx, csch_cgrp_t *parent, double cx, double cy, double r, const char *stroke_name, const char *fill_name);
+
+
 /* Create a terminal that has a single line in it; frees src;
    returns the terminal group */
 csch_chdr_t *csch_alien_mkpin_line(csch_alien_read_ctx_t *ctx, csch_source_arg_t *src, csch_cgrp_t *parent, double x1, double y1, double x2, double y2);
