@@ -211,6 +211,37 @@ fgw_error_t csch_act_proptoggle(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
+static const char csch_acts_propdel[] = "propdel([scope], key, [regex])";
+static const char csch_acth_propdel[] = "Delete attribute(s) by key; if the third attribute has a value of true, delete any attribute that matches the regular expression in key (the regex still needs to be prefixed by a/ to indicate it is addressing attributes)";
+fgw_error_t csch_act_propdel(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	rnd_design_t *hl = RND_ACT_DESIGN;
+	csch_sheet_t *sheet = (csch_sheet_t *)hl;
+	const char *first, *name, *regex = NULL;
+	csch_propedit_t ctx;
+
+	csch_props_init(&ctx, sheet, &sheet->direct);
+
+	RND_ACT_CONVARG(1, FGW_STR, propdel, first = argv[1].val.str);
+	if (prop_scope_add(&ctx, first, 1) == 0) {
+		RND_ACT_CONVARG(2, FGW_STR, propdel, name = argv[2].val.str);
+		RND_ACT_MAY_CONVARG(3, FGW_STR, propdel, regex = argv[3].val.str);
+	}
+	else {
+		name = first;
+		RND_ACT_MAY_CONVARG(2, FGW_STR, propdel, regex = argv[2].val.str);
+		ctx.use_selection = 1;
+	}
+
+	ctx.aregex = rnd_istrue(regex);
+	csch_propsel_del(&ctx, name);
+	prop_scope_finish(&ctx);
+	csch_props_uninit(&ctx);
+
+	RND_ACT_IRES(0);
+	return 0;
+}
+
 
 static const char csch_acts_propget[] = "propget([scope], name, [stattype])";
 static const char csch_acth_propget[] = "Return the named property of scope or all selected objects to/by value. Scope is documented at PropEdit().";
@@ -380,6 +411,7 @@ static rnd_action_t sch_propedit_action_list[] = {
 	{"propprint", csch_act_propprint, csch_acth_propprint, csch_acts_propprint},
 	{"propset", csch_act_propset, csch_acth_propset, csch_acts_propset},
 	{"proptoggle", csch_act_proptoggle, csch_acth_proptoggle, csch_acts_proptoggle},
+	{"propdel", csch_act_propdel, csch_acth_propdel, csch_acts_propdel},
 	{"propget", csch_act_propget, csch_acth_propget, csch_acts_propget}
 };
 
