@@ -102,6 +102,10 @@ typedef struct {
 	unsigned use_selection:1;  /* all selected objects on the current pcb */
 	unsigned use_sheet:1;      /* run on the board too */
 	unsigned geo:1;            /* include fields related to geometry of objects */
+	unsigned aregex:1;         /* when 1, attribute key is a regex */
+
+	/* internal/cache */
+	void *rx;
 } csch_propedit_t;
 
 /* A property list (props) is a string->csch_props_t. Each entry is a named
