@@ -36,6 +36,7 @@
 #include <librnd/core/rnd_conf.h>
 #include <librnd/core/error.h>
 #include <librnd/core/math_helper.h>
+#include <genregex/regex_se.h>
 
 #include <libcschem/concrete.h>
 #include <libcschem/cnc_line.h>
@@ -852,10 +853,27 @@ int csch_propsel_toggle(csch_propedit_t *ctx, const char *prop, rnd_bool create)
 
 static long del_attr(csch_propedit_t *ctx, csch_chdr_t *obj, const char *key)
 {
+	csch_cgrp_t *grp = (csch_cgrp_t *)obj;
 	if (!csch_obj_is_grp(obj))
 		return 0;
 
-	csch_attr_modify_del(ctx->sheet, (csch_cgrp_t *)obj, key, 1);
+	if (ctx->aregex) {
+		htsp_entry_t *e;
+
+		if (ctx->rx == NULL)
+			ctx->rx = re_se_comp(key);
+
+		restart:;
+		for(e = htsp_first(&grp->attr); e != NULL; e = htsp_next(&grp->attr, e)) {
+			csch_attrib_t *a = e->value;
+			if (re_se_exec(ctx->rx, a->key)) {
+				csch_attr_modify_del(ctx->sheet, grp, a->key, 1);
+				goto restart; /* the hash table iterator breaks; we expect only a few matching attributes so it is probably cheap to restart */
+			}
+		}
+	}
+	else
+		csch_attr_modify_del(ctx->sheet, grp, key, 1);
 	return 1;
 }
 
