@@ -1,8 +1,10 @@
 /*
  *                            COPYRIGHT
  *
- *  pcb-rnd, interactive printed circuit board design
- *  Copyright (C) 2019 Tibor 'Igor2' Palinkas
+ *  sch-rnd - modular/flexible schematics editor - query
+ *  Copyright (C) 2019, 2024 Tibor 'Igor2' Palinkas
+ *
+ *  copied from: pcb-rnd, interactive printed circuit board design
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,6 +36,8 @@
 #include <librnd/core/actions.h>
 #include <librnd/core/conf_hid.h>
 #include <librnd/core/rnd_conf.h>
+#include <librnd/core/compat_fs.h>
+#include <librnd/core/project.h>
 #include <librnd/hid/hid_dad.h>
 #include <librnd/core/event.h>
 #include <librnd/core/error.h>
@@ -62,7 +66,8 @@ typedef struct {
 
 typedef struct{
 	RND_DAD_DECL_NOINIT(dlg)
-	int wexpr_str, wwizard, wact, wscope;
+	rnd_design_t *dsg;   /* used when follow is set */
+	int wexpr_str, wwizard, wact, wscope, wscope_label, wfollow;
 	int wrowbox[MAX_ROW];
 	int wexpr[MAX_ROW][MAX_COL]; /* expression framed box */
 	int wexpr_lab[MAX_ROW][MAX_COL]; /* the label within the expression box */
@@ -136,6 +141,59 @@ static void update_vis(search_ctx_t *ctx)
 	rnd_gui->attr_dlg_widget_state(ctx->dlg_hid_ctx, ctx->wexpr_str, !wen);
 }
 
+static rnd_design_t *get_design(search_ctx_t *ctx)
+{
+	
+	if (ctx->dlg[ctx->wfollow].val.lng)
+		return ctx->dsg;
+	return rnd_gui->get_dad_design(ctx->dlg_hid_ctx);
+}
+
+static void update_scope(search_ctx_t *ctx)
+{
+	rnd_hid_attr_val_t hv;
+	rnd_design_t *ctx_hl = get_design(ctx);
+
+	rnd_project_t *prj = ctx_hl->project;
+	char *freeme = NULL;
+
+	if (ctx_hl != NULL) {
+		switch(ctx->dlg[ctx->wscope].val.lng) {
+			case 0:
+				if (ctx_hl->loadname != NULL)
+					hv.str = ctx_hl->loadname;
+				else
+					hv.str = "<unknown sheet>";
+				break;
+			case 1:
+				if (prj->loadname != NULL) {
+					freeme = rnd_dirname(prj->loadname);
+					hv.str = rnd_basename(freeme);
+				}
+				else
+					hv.str = "<unknown project>";
+				break;
+			default:
+				hv.str = "<unknown scope>";
+				break;
+		}
+	}
+	else
+		hv.str = "<invalid scope>";
+
+	rnd_gui->attr_dlg_set_value(ctx->dlg_hid_ctx, ctx->wscope_label, &hv);
+	free(freeme);
+}
+
+static void maybe_follow(search_ctx_t *ctx, rnd_design_t *dsg)
+{
+	if (!ctx->dlg[ctx->wfollow].val.lng)
+		return;
+
+	ctx->dsg = dsg;
+	update_scope(ctx);
+}
+
 /* look up row and col for a widget attr in a [row][col] widget idx array; returns 0 on success */
 static int rc_lookup(search_ctx_t *ctx, int w[MAX_ROW][MAX_COL], rnd_hid_attribute_t *attr, int *row, int *col)
 {
@@ -473,7 +531,11 @@ static void search_append_row_cb(void *hid_ctx, void *caller_data, rnd_hid_attri
 static void search_apply_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
 {
 	search_ctx_t *ctx = caller_data;
-	rnd_design_t *hidlib = rnd_gui->get_dad_design(hid_ctx);
+	rnd_design_t *hidlib = get_design(ctx);
+	if (hidlib == NULL) {
+		rnd_message(RND_MSG_ERROR, "Can't search: invalid scope\n");
+		return;
+	}
 	if (ctx->dlg[ctx->wexpr_str].val.str != NULL) {
 		const char *op = search_acts[ctx->dlg[ctx->wact].val.lng];
 		const char *scp = search_scopes[ctx->dlg[ctx->wscope].val.lng];
@@ -483,6 +545,18 @@ static void search_apply_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_
 	}
 }
 
+static void search_scope_chg_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	search_ctx_t *ctx = caller_data;
+	update_scope(ctx);
+}
+
+static void search_follow_chg_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute_t *attr)
+{
+	search_ctx_t *ctx = caller_data;
+	maybe_follow(ctx, rnd_multi_get_current());
+}
+
 
 static const char *icon_del[] = {
 "5 5 2 1",
@@ -511,6 +585,7 @@ static void search_window_create(void)
 	rnd_hid_dad_buttons_t clbtn[] = {{"Close", 0}, {NULL, 0}};
 	search_ctx_t *ctx = calloc(sizeof(search_ctx_t), 1);
 	int row, col;
+	static const char *help_follow = "When ticked: the scope of dialog box follows sheet switches";
 
 	gdl_append(&searches, ctx, link);
 
@@ -527,6 +602,23 @@ static void search_window_create(void)
 			RND_DAD_LABEL(ctx->dlg, "Scope:");
 			RND_DAD_ENUM(ctx->dlg, search_scopes);
 				ctx->wscope = RND_DAD_CURRENT(ctx->dlg);
+				RND_DAD_CHANGE_CB(ctx->dlg, search_scope_chg_cb);
+			RND_DAD_BEGIN_VBOX(ctx->dlg);
+				RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_TIGHT);
+				RND_DAD_LABEL(ctx->dlg, "<project name>");
+					ctx->wscope_label = RND_DAD_CURRENT(ctx->dlg);
+					RND_DAD_HELP(ctx->dlg, "Searches done from this dialog box will search in this scope (sheet or project)");
+				RND_DAD_BEGIN_HBOX(ctx->dlg);
+					RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_TIGHT);
+					RND_DAD_LABEL(ctx->dlg, "Follow:");
+						RND_DAD_HELP(ctx->dlg, help_follow);
+					RND_DAD_BOOL(ctx->dlg);
+						ctx->wfollow = RND_DAD_CURRENT(ctx->dlg);
+						RND_DAD_HELP(ctx->dlg, help_follow);
+						RND_DAD_DEFAULT_NUM(ctx->dlg, 0);
+						RND_DAD_CHANGE_CB(ctx->dlg, search_follow_chg_cb);
+				RND_DAD_END(ctx->dlg);
+			RND_DAD_END(ctx->dlg);
 		RND_DAD_END(ctx->dlg);
 		RND_DAD_BEGIN_VBOX(ctx->dlg);
 			RND_DAD_COMPFLAG(ctx->dlg, RND_HATF_FRAME | RND_HATF_EXPFILL | RND_HATF_SCROLL);
@@ -597,8 +689,10 @@ static void search_window_create(void)
 	RND_DAD_DEFSIZE(ctx->dlg, 300, 350);
 	RND_DAD_NEW("search", ctx->dlg, "sch-rnd search", ctx, rnd_false, search_close_cb); /* type=local */
 
+	ctx->dsg = rnd_gui->get_dad_design(ctx->dlg_hid_ctx);
 	ctx->visible[0][0] = 1;
 	update_vis(ctx);
+	update_scope(ctx);
 	search_recompile(ctx);
 }
 
@@ -623,13 +717,22 @@ void sch_rnd_query_ev_preunload(rnd_design_t *hidlib, void *user_data, int argc,
 {
 	search_ctx_t *ctx, *nextctx;
 	for(ctx = gdl_first(&searches); ctx != NULL; ctx = nextctx) {
-		rnd_design_t *ctx_hl = rnd_gui->get_dad_design(ctx->dlg_hid_ctx);
+		rnd_design_t *ctx_hl = get_design(ctx);
 		nextctx = gdl_next(&searches, ctx);
 		if (ctx_hl == hidlib)
 			search_close(ctx);
 	}
 }
 
+void sch_rnd_query_ev_sheet_chg(rnd_design_t *hidlib, void *user_data, int argc, rnd_event_arg_t argv[])
+{
+	search_ctx_t *ctx;
+	rnd_design_t *dsg = argv[1].d.p;
+	for(ctx = gdl_first(&searches); ctx != NULL; ctx = gdl_next(&searches, ctx))
+		maybe_follow(ctx, dsg);
+}
+
+
 void sch_rnd_search_close_all(void)
 {
 	search_ctx_t *ctx, *nextctx;
