@@ -3,7 +3,7 @@
  *
  *  pcb-rnd, interactive printed circuit board design
  *  Copyright (C) 2016,2019,2020 Tibor 'Igor2' Palinkas
- *  Copyright (C) 2022 Tibor 'Igor2' Palinkas (slight modifications for sch-rnd)
+ *  Copyright (C) 2022, 2023 Tibor 'Igor2' Palinkas (slight modifications for sch-rnd)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -43,6 +43,7 @@
 #include <libcschem/cnc_any_obj.h>
 #include "dlg_search.h"
 #include <librnd/core/compat_misc.h>
+#include <librnd/core/project.h>
 #include <librnd/hid/hid.h>
 
 static const char csch_acts_query[] =
@@ -176,7 +177,8 @@ pcb_qry_node_t *pcb_query_compile(const char *script)
 int pcb_qry_run_script(pcb_qry_exec_t *ec, csch_sheet_t *sheet, const char *script, const char *scope, void (*cb)(void *user_ctx, pcb_qry_val_t *res, csch_chdr_t *current), void *user_ctx)
 {
 	pcb_qry_node_t *prg = NULL;
-	int res, bufno = -1; /* empty scope means board */
+	int res;
+	int project_scope = 0, bufno = -1; /* empty scope means board */
 
 	if (script == NULL) {
 		rnd_message(RND_MSG_ERROR, "Compilation error: no script specified.\n");
@@ -193,7 +195,11 @@ int pcb_qry_run_script(pcb_qry_exec_t *ec, csch_sheet_t *sheet, const char *scri
 
 	/* decode scope and set bufno */
 	if ((scope != NULL) && (*scope != '\0')) {
-		if (strcmp(scope, "sheet") == 0) bufno = -1;
+		if (strcmp(scope, "project") == 0) {
+			bufno = -1;
+			project_scope = 1;
+		}
+		else if (strcmp(scope, "sheet") == 0) bufno = -1;
 		else if (strcmp(scope, "sheet-indirect") == 0) bufno = -2;
 		else if (strncmp(scope, "buffer", 6) == 0) {
 			scope += 6;
@@ -221,8 +227,22 @@ int pcb_qry_run_script(pcb_qry_exec_t *ec, csch_sheet_t *sheet, const char *scri
 			return -1;
 		}
 	}
-	
-	res = pcb_qry_run(ec, sheet, prg, bufno, cb, user_ctx);
+
+	if (project_scope) {
+		long n;
+		rnd_project_t *prj = sheet->hidlib.project;
+
+		for(n = 0; n < prj->designs.used; n++) {
+			int r = pcb_qry_run(ec, prj->designs.array[n], prg, bufno, cb, user_ctx);
+			if (r < 0) {
+				res = r;
+				break;
+			}
+			res += r;
+		}
+	}
+	else
+		res = pcb_qry_run(ec, sheet, prg, bufno, cb, user_ctx);
 	pcb_qry_n_free(prg);
 	return res;
 }
@@ -408,6 +428,7 @@ static fgw_error_t csch_act_query(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		fgw_arg_t args[4], ares;
 		vtp0_t arr = {0};
 		RND_ACT_MAY_CONVARG(2, FGW_STR, query, arg = argv[2].val.str);
+		RND_ACT_MAY_CONVARG(3, FGW_STR, query, scope = argv[3].val.str);
 		if (pcb_qry_run_script(NULL, sheet, arg, scope, view_cb, &arr) >= 0) {
 			args[1].type = FGW_STR; args[1].val.str = "objarr";
 			fgw_ptr_reg(&rnd_fgw, &args[2], CSCH_PTR_DOMAIN_COBJ_ARR, FGW_PTR | FGW_STRUCT, &arr);
