@@ -383,6 +383,9 @@ static void attr_val_set_meta_and_str(attrdlg_ctx_t *ctx, csch_attrib_t *a, int
 	if ((key == NULL) || (*key == '\0'))
 		return; /* do not allow empty key */
 
+	if (val == NULL)
+		val = ""; /* empty is an empty string; NULL would be an array */
+
 	if (strcmp(key, a->key) != 0) {
 		/* key change: rename attrib */
 		ctx->refresh_lock++;
@@ -430,6 +433,9 @@ static void attr_strval_set_cb(void *hid_ctx, void *caller_data, rnd_hid_attribu
 		key = ctx->dlg[ctx->wkey].val.str;
 		val = ctx->dlg[ctx->wval_str].val.str;
 
+		if (val == NULL)
+			val = ""; /* NULL means array, empty is done using an empty string */
+
 		ctx->refresh_lock++;
 		csch_attr_modify_str(ctx->sheet, ctx->obj, prio, key, val, attrdlg_src(), 1);
 		ctx->refresh_lock--;
@@ -702,9 +708,17 @@ static void attr_afloater_cb(void *hid_ctx, void *caller_data, rnd_hid_attribute
 
 	penname = (grp->role == CSCH_ROLE_WIRE_NET ? "wire" : "sym-secondary");
 
-	templ = rnd_strdup_printf("%%../a.%s%%", r->cell[0]); /* use the abstract attribute */
-	csch_auto_attr_place(ctx->sheet, grp, r->cell[0], penname, templ, ctx->ch_xy);
-	free(templ);
+	if (grp->hdr.type == CSCH_CTYPE_GRP) {
+		if (r == NULL) {
+			rnd_message(RND_MSG_ERROR, "First select an abstract model attribe!\n");
+			return;
+		}
+		templ = rnd_strdup_printf("%%../a.%s%%", r->cell[0]); /* use the abstract attribute */
+		csch_auto_attr_place(ctx->sheet, grp, r->cell[0], penname, templ, ctx->ch_xy);
+		free(templ);
+	}
+	else
+		rnd_message(RND_MSG_ERROR, "Can not create floater on group ref object.\nIf this is a symbol from a local lib: can not modify instance (by creating a text object for the floater); embed it first to have a non-local-lib copy that can be modified.\n");
 }
 
 
