@@ -101,6 +101,8 @@ static void cond_apply(cond_dlg_ctx_t *ctx)
 		vts0_append(&lst, s);
 	}
 
+	/* this can not be csch_cobj_attrib_set() because it is setting a list;
+	   it's also attr_name is rather limited so side effects won't play a role */
 	csch_attrib_set_arr(&obj->attr, CSCH_ATP_USER_DEFAULT, ctx->attr_name, &lst, src, NULL);
 	csch_sheet_set_changed(obj->hdr.sheet, 1);
 	free(tmp);
