@@ -195,7 +195,7 @@ static void qa_connect_add_cb(void *hid_ctx, void *caller_data, rnd_hid_attribut
 }
 
 const char csch_acts_quick_attr_connect[] = "quick_attr_connect(objptr)";
-const char csch_acth_quick_attr_connect[] = "Qucik Attribute Edit for core data model's symbol connect attribute (attribute based symbol terminal to network connection table)";
+const char csch_acth_quick_attr_connect[] = "Quick Attribute Edit for core data model's symbol connect attribute (attribute based symbol terminal to network connection table)";
 fgw_error_t csch_act_quick_attr_connect(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	qa_connect_t ctx = {0};
