@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - standard cschem attributes
+ *  sch-rnd - modular/flexible schematics editor - standard cschem attributes
  *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
@@ -39,6 +39,7 @@
 #include <libcschem/attrib.h>
 #include <libcschem/libcschem.h>
 #include <libcschem/util_compile.h>
+#include <libcschem/hierarchy.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/compat_misc.h>
 #include <librnd/core/rnd_printf.h>
@@ -61,32 +62,99 @@ static const char std_cschem_cookie[] = "std_cschem";
 
 /*** hooks ***/
 
+RND_INLINE fgw_error_t render_hier_netname(fgw_arg_t *res, gds_t *prefix, const char *sname)
+{
+	gds_t tmp;
+
+	gds_init(&tmp);
+	gds_append_len(&tmp, prefix->array, prefix->used);
+	gds_append_str(&tmp, sname);
+	res->type = FGW_STR | FGW_DYN;
+	res->val.str = tmp.array;
+
+	return 0;
+}
+
+fgw_error_t std_cschem_wirenet_name_to_net_name(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	const char *sname;
+	csch_hier_path_t *hpath;
+	csch_chdr_t *wnet;
+
+	CSCH_HOOK_CONVARG(1, FGW_STR,  std_cschem_wirenet_name_to_net_name, sname = argv[1].val.cstr);
+	CSCH_HOOK_CONVARG(2, FGW_COBJ, std_cschem_wirenet_name_to_net_name, wnet = fgw_cobj(&argv[2]));
+	CSCH_HOOK_CONVARG(3, FGW_HPATH, std_cschem_wirenet_name_to_net_name, hpath = fgw_hpath(&argv[3]));
+
+	if (sname == NULL)
+		return 0;
+
+	return render_hier_netname(res, &hpath->prefix, sname);
+}
+
+fgw_error_t std_cschem_attrib_net_name_to_net_name(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	const char *sname;
+	csch_hier_path_t *hpath;
+	csch_acomp_t *acomp;
+	gds_t prefix = {0};
+	fgw_error_t retval;
+
+	CSCH_HOOK_CONVARG(1, FGW_STR,  std_cschem_attrib_net_name_to_net_name, sname = argv[1].val.cstr);
+	CSCH_HOOK_CONVARG(2, FGW_AOBJ, std_cschem_attrib_net_name_to_net_name, acomp = fgw_aobj(&argv[2]));
+
+	if (sname == NULL)
+		return 0;
+
+	csch_hier_build_path(&prefix, acomp->hlev);
+	retval = render_hier_netname(res, &prefix, sname);
+	gds_uninit(&prefix);
+
+	return retval;
+}
+
 fgw_error_t std_cschem_symbol_name_to_component_name(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 	const char *sname, *end;
 	int preflen;
 	gds_t tmp;
 	csch_chdr_t *sym, *o;
+	csch_hier_path_t *hpath;
+
 /*	fgw_obj_t *obj = argv[0].val.argv0.func->obj;*/
 /*	std_cschem_ctx_t *ctx = obj->script_data; */
 
-	if (!std_cschem_conf.plugins.std_cschem.fix_unnamed_syms)
-		return 0;
-
 	CSCH_HOOK_CONVARG(1, FGW_STR,  std_cschem_symbol_name_to_component_name, sname = argv[1].val.cstr);
 	CSCH_HOOK_CONVARG(2, FGW_COBJ, std_cschem_symbol_name_to_component_name, sym = fgw_cobj(&argv[2]));
+	CSCH_HOOK_CONVARG(3, FGW_HPATH, std_cschem_symbol_name_to_component_name, hpath = fgw_hpath(&argv[3]));
 
 	if (sname == NULL)
 		return 0;
 
+
+	if (!std_cschem_conf.plugins.std_cschem.fix_unnamed_syms) {
+		normal_hprefix:;
+		if (hpath->prefix.used > 0) { /* apply hierarchic prefix */ 
+			gds_init(&tmp);
+			gds_append_len(&tmp, hpath->prefix.array, hpath->prefix.used);
+			gds_append_str(&tmp, sname);
+			res->type = FGW_STR | FGW_DYN;
+			res->val.str = tmp.array;
+		}
+		return 0;
+	}
+
 	end = sname + strlen(sname) - 1;
 	if (*end != '?')
-		return 0;
+		goto normal_hprefix;
 
 	while((*end == '?') && (end >= sname)) end--;
 	preflen = end - sname + 1;
 
 	gds_init(&tmp);
+
+	if (hpath->prefix.used > 0)
+		gds_append_len(&tmp, hpath->prefix.array, hpath->prefix.used);
+
 	if (preflen > 0)
 		gds_append_len(&tmp, sname, preflen);
 	else
@@ -109,6 +177,7 @@ fgw_error_t std_cschem_compile_comp1(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
 /*	fgw_obj_t *obj = argv[0].val.argv0.func->obj;*/
 /*	std_cschem_ctx_t *ctx = obj->script_data; */
+	csch_hook_call_ctx_t *cctx = argv[0].val.argv0.user_call_ctx;
 	csch_acomp_t *comp;
 	const csch_attrib_t *conn;
 	long n;
@@ -152,7 +221,7 @@ fgw_error_t std_cschem_compile_comp1(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 		*netname = '\0';
 		netname++;
 
-		if (csch_cmp_nameconn_port_net(comp, portname, netname, 1) < 0) {
+		if (csch_cmp_nameconn_port_net(cctx->project, comp, portname, netname, 1, cctx->view_id, cctx->hpath) < 0) {
 			csch_aport_t *port = csch_aport_get(comp->hdr.abst, comp, portname, 1);
 			rnd_message(RND_MSG_ERROR, "Abstract component ('%s') 'connect' attribute failed: '%s'\n", comp->name, conn->arr.array[n]);
 			if (port->conn.net == NULL) {
@@ -172,6 +241,8 @@ fgw_error_t std_cschem_compile_comp1(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 
 static int on_load(fgw_obj_t *obj, const char *filename, const char *opts)
 {
+	fgw_func_reg(obj, "wirenet_name_to_net_name", std_cschem_wirenet_name_to_net_name);
+	fgw_func_reg(obj, "attrib_net_name_to_net_name", std_cschem_attrib_net_name_to_net_name);
 	fgw_func_reg(obj, "symbol_name_to_component_name", std_cschem_symbol_name_to_component_name);
 	fgw_func_reg(obj, "compile_component1", std_cschem_compile_comp1);
 
