@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - standard device mapper
+ *  sch-rnd - modular/flexible schematics editor - standard device mapper
  *  Copyright (C) 2019,2020,2022,2023 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 Entrust Fund in 2023)
@@ -51,6 +51,7 @@
 #include <libcschem/event.h>
 #include <libcschem/util_parse.h>
 #include <libcschem/operation.h>
+#include <libcschem/hierarchy.h>
 #include <librnd/core/misc_util.h>
 #include <librnd/core/actions.h>
 #include <librnd/core/compat_misc.h>
