@@ -455,7 +455,7 @@ int forge_condition_get_test_bench(vts0_t *dst, const char *objtype, const char
 	return fc_test_bench_rev(dst, fc, &start);
 }
 
-
+static gds_t forge_if_tmp = {0};
 static int forge_apply(const char *objtype, const char *objname, csch_ahdr_t *aobj, int prio)
 {
 	const csch_attrib_t *forge;
@@ -471,15 +471,34 @@ static int forge_apply(const char *objtype, const char *objname, csch_ahdr_t *ao
 			r |= forge_exec(aobj, forge->arr.array[n], prio, "forge");
 	}
 
-	/* conditionals */
+	/* conditionals: first collect a list of attrib keys to execute; can't
+	   execute immediately because that may change aobj->attr which could
+	   confuse the iterator */
+	forge_if_tmp.used = 0;
 	for(e = htsp_first(&aobj->attr); (e != NULL) && (r == 0); e = htsp_next(&aobj->attr, e)) {
 		csch_attrib_t *a = e->value;
 
 		if (a->deleted || (a->arr.used < 2) || (e->key[0] != 'f') || (strncmp(e->key, "forge-if/", 9) != 0))
 			continue;
-
 		/* execute */
 		if (forge_condition(objtype, objname, aobj, e->key, a->arr.array[0])) {
+			gds_append_str(&forge_if_tmp, e->key);
+			gds_append(&forge_if_tmp, '\0');
+		}
+	}
+
+	/* now execute each */
+	for(n = 0; n < forge_if_tmp.used;) {
+		char *key = forge_if_tmp.array+n;
+
+		n += strlen(key)+1;
+		if (*key == '\0') break;
+
+		e = htsp_getentry(&aobj->attr, key);
+		if (e != NULL) {
+			long n;
+			csch_attrib_t *a = e->value;
+
 			for(n = 1; (r == 0) && (n < a->arr.used); n++)
 				r |= forge_exec(aobj, a->arr.array[n], prio, e->key);
 		}
@@ -562,6 +581,7 @@ int pplg_check_ver_std_forge(int ver_needed) { return 0; }
 void pplg_uninit_std_forge(void)
 {
 	gds_uninit(&stmp);
+	gds_uninit(&forge_if_tmp);
 	csch_dlg_test_bench_uninit();
 	vtl0_uninit(&cond_stack);
 	genht_uninit_deep(htsp, &cond_cache, {
