@@ -9,6 +9,7 @@ typedef struct {
 			RND_CFT_REAL file_changed_interval;    /* how often to check if the file has changed on the disk (in seconds); 0 or negative means no check at all */
 			RND_CFT_INTEGER backup_interval;       /* time between two backups in seconds; 0 means disabled (no backups) */
 			RND_CFT_LIST library_search_paths;     /* ordered list of paths that are each recursively searched for symbol files */
+			RND_CFT_LIST hlibrary_search_paths;    /* ordered list of paths that are each recursively searched for external hierarchic child sheets */
 
 			RND_CFT_STRING emergency_name;         /* file name template for emergency save anonymous .sch files (when sch-rnd crashes); optional field: first %ld --> pid, second %ld --> sheet uid; must be shorter than 240 characters. Don't do emergency save if this item is empty. */
 			RND_CFT_STRING backup_name;            /* file name template for periodic backup of board files; optional fields (the usual % substitutions work) */
@@ -90,7 +91,11 @@ typedef struct {
 		} color;
 	} appearance;
 	const struct compile {
-		RND_CFT_BOOLEAN multiport_net_merge; /* when multiple ports with the same component:port name connect to different nets: if true, allow merging those nets, else throw an error */
+		RND_CFT_BOOLEAN multiport_net_merge;       /* when multiple ports with the same component:port name connect to different nets: if true, allow merging those nets, else throw an error */
+		const struct hierarchic {
+			RND_CFT_BOOLEAN net_allow_rename;        /* When false: throw an error if a network is named on both parent and child side of a hierarchic descend; otherwise use net_rename_prefer_top to decide which name to keep; best place to set this is the project role. */
+			RND_CFT_BOOLEAN net_rename_prefer_top;   /* If net_allow_rename==true, this decides whether to prefer parent (top) sheet's net name (true) or child (bottom) sheet's net name (false) when merging the two nets; best place to set this is the project role. */
+		} hierarchic;
 		RND_CFT_HLIST views;
 	} compile;
 	const struct prj {
