@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - sch-rnd (executable)
+ *  sch-rnd - modular/flexible schematics editor - sch-rnd (executable)
  *  Copyright (C) 2019 Tibor 'Igor2' Palinkas
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -56,8 +56,8 @@ void sch_rnd_hidlib_crosshair_move_to(rnd_design_t *hl, rnd_coord_t abs_x, rnd_c
 	/* update the GUI, emit events */
 	rnd_hid_notify_crosshair_change(hl, rnd_false);
 
-	sch_rnd_crosshair_x = abs_x;
-	sch_rnd_crosshair_y = abs_y;
+	hl->ch_x = sch_rnd_crosshair_x = abs_x;
+	hl->ch_y = sch_rnd_crosshair_y = abs_y;
 
 	rnd_gui->set_crosshair(rnd_gui, abs_x, abs_y, 0);
 	rnd_tool_adjust_attached(hl);
