@@ -1,7 +1,7 @@
 /*
  *                            COPYRIGHT
  *
- *  cschem - modular/flexible schematics editor - sch-rnd (executable)
+ *  sch-rnd - modular/flexible schematics editor - sch-rnd (executable)
  *  Copyright (C) 2022 Tibor 'Igor2' Palinkas
  *
  *  (Supported by NLnet NGI0 PET Fund in 2022)
@@ -43,6 +43,8 @@
 #include <librnd/core/error.h>
 #include <librnd/core/safe_fs.h>
 
+#include "sheet.h"
+
 #include "export.h"
 
 sch_rnd_export_appspec_t sch_rnd_no_appspec = {0};
@@ -161,6 +163,7 @@ static int sch_rnd_export_prj_sheets_multifile(rnd_hid_t *hid, rnd_design_t *des
 
 	appspec->fn_page_suffix = fn_page_suffix;
 	for(page = 0; page < design->project->designs.used; page++) {
+		sch_rnd_sheet_recalc_bbox((csch_sheet_t *)design->project->designs.array[page]);
 		sprintf(fn_page_suffix, "-p%ld", page+1);
 		res |= exp_sheet(hid, design->project->designs.array[page], options, appspec, &ovr);
 	}
@@ -173,5 +176,7 @@ int sch_rnd_export_project_or_sheet(rnd_hid_t *hid, rnd_design_t *design, rnd_hi
 {
 	if (appspec->exp_prj)
 		return sch_rnd_export_prj_sheets_multifile(hid, design, options, appspec, exp_sheet);
+
+	sch_rnd_sheet_recalc_bbox((csch_sheet_t *)design);
 	return exp_sheet(hid, design, options, appspec, NULL);
-}
\ No newline at end of file
+}
