@@ -69,7 +69,6 @@ static const char csch_acts_Quit[] = "Quit()";
 static const char csch_acth_Quit[] = "Quits sch-rnd after confirming.";
 static fgw_error_t csch_act_Quit(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 {
-	csch_sheet_t *sheet = CSCH_ACT_SHEET;
 	const char *force = NULL;
 	RND_ACT_MAY_CONVARG(1, FGW_STR, Quit, force = argv[1].val.str);
 
@@ -303,6 +302,44 @@ fgw_error_t csch_act_New(fgw_arg_t *res, int argc, fgw_arg_t *argv)
 	return 0;
 }
 
+static const char csch_acts_ImportAttbl[] = "ImportAttbl([path, [fmt]])";
+static const char csch_acth_ImportAttbl[] = "Import an attribute table file and make modifications to the concrete model or generate back annotation for the abstract model";
+fgw_error_t csch_act_ImportAttbl(fgw_arg_t *res, int argc, fgw_arg_t *argv)
+{
+	const char *fn = NULL, *fmt = NULL;
+	csch_sheet_t *sheet = CSCH_ACT_SHEET;
+
+	RND_ACT_MAY_CONVARG(1, FGW_STR, ImportAttbl, fn = argv[1].val.str);
+	RND_ACT_MAY_CONVARG(2, FGW_STR, ImportAttbl, fmt = argv[2].val.str);
+
+	if (fn == NULL) {
+		static char *default_file = NULL;
+		static const char *flt_table[] = {"*.csv", NULL};
+		static const char *flt_any[] = {"*", "*.*", NULL};
+		const rnd_hid_fsd_filter_t flt[] = {
+			{"tables",                             NULL, flt_table},
+			{"all",                                NULL, flt_any},
+			{NULL, NULL,NULL}
+		};
+
+		fn = rnd_hid_fileselect(rnd_gui,
+			"Import attribute table...", "Picks an attribute table to import and appy\n",
+			default_file, ".csv", flt, "attbl", RND_HID_FSD_READ, NULL);
+
+		free(default_file);
+		default_file = NULL;
+
+		if (fn == NULL) {
+			RND_ACT_IRES(1);
+			return 0; /* cancel */
+		}
+	}
+
+	RND_ACT_IRES(csch_import_attbl(&sheet->hidlib, fn, fmt));
+
+	return 0;
+}
+
 static const char csch_acts_ProjectNew[] = "ProjectNew([path])";
 static const char csch_acth_ProjectNew[] = "Create a new project";
 fgw_error_t csch_act_ProjectNew(fgw_arg_t *res, int argc, fgw_arg_t *argv)
@@ -610,6 +647,7 @@ static rnd_action_t file_action_list[] = {
 	{"Revert", csch_act_Revert, csch_acth_Revert, csch_acts_Revert},
 	{"New", csch_act_New, csch_acth_New, csch_acts_New},
 	{"Export", rnd_act_Export, rnd_acth_Export, rnd_acts_Export},
+	{"ImportAttbl", csch_act_ImportAttbl, csch_acth_ImportAttbl, csch_acts_ImportAttbl},
 	{"ProjectNew", csch_act_ProjectNew, csch_acth_ProjectNew, csch_acts_ProjectNew},
 	{"ProjectLoadPartial", csch_act_ProjectLoadPartial, csch_acth_ProjectLoadPartial, csch_acts_ProjectLoadPartial},
 	{"ProjectSheetType", csch_act_ProjectSheetType, csch_acth_ProjectSheetType, csch_acts_ProjectSheetType},
