@@ -9,6 +9,8 @@ action_entry(AllProject)
 action_entry(Any)
 action_entry(Auto)
 action_entry(Buffer)
+action_entry(ConvFrom)
+action_entry(Edit)
 action_entry(Global)
 action_entry(Group)
 action_entry(Horizontal)
@@ -31,4 +33,5 @@ action_entry(Term)
 action_entry(Terminal)
 action_entry(TextHeight)
 action_entry(TextWidth)
+action_entry(Update)
 action_entry(Vertical)
