@@ -71,6 +71,7 @@
 #include "project.h"
 #include "multi.h"
 #include "plug_io_act.h"
+#include "extobj_act.h"
 #include "export.h"
 
 csch_chdr_t *csch_obj_clicked = NULL;
@@ -274,6 +275,7 @@ static void sch_rnd_main_init(void)
 	sch_rnd_file_act_init2();
 	sch_rnd_font_act_init2();
 	sch_rnd_select_act_init2();
+	sch_rnd_extobj_act_init();
 	sch_rnd_font_init2();
 	sch_rnd_draw_init2();
 	sch_rnd_buffer_init2();
@@ -310,6 +312,7 @@ void sch_rnd_main_uninit(void)
 	sch_rnd_multi_uninit();
 	rnd_funchash_uninit();
 	csch_plug_io_act_uninit();
+	sch_rnd_extobj_act_uninit();
 	csch_uninit();
 	sch_rnd_draw_uninit();
 	sch_rnd_font_uninit();
